@@ -65,6 +65,7 @@ void ApplicationActionController::init()
     dispatcher()->reg(this, "about-musicxml", this, &ApplicationActionController::openAboutMusicXMLDialog);
     dispatcher()->reg(this, "online-handbook", this, &ApplicationActionController::openOnlineHandbookPage);
     dispatcher()->reg(this, "ask-help", this, &ApplicationActionController::openAskForHelpPage);
+    dispatcher()->reg(this, "accessibility-statement", this, &ApplicationActionController::openAccessibilityStatementPage);
     dispatcher()->reg(this, "preference-dialog", this, &ApplicationActionController::openPreferencesDialog);
 
     dispatcher()->reg(this, "revert-factory", this, &ApplicationActionController::revertToFactorySettings);
@@ -284,6 +285,12 @@ void ApplicationActionController::openAskForHelpPage()
     interactive()->openUrl(askForHelpUrl);
 }
 
+void ApplicationActionController::openAccessibilityStatementPage()
+{
+    std::string accessibilityStatementUrl = configuration()->accessibilityStatementUrl();
+    interactive()->openUrl(accessibilityStatementUrl);
+}
+
 void ApplicationActionController::openPreferencesDialog()
 {
     const context::IPlaybackStatePtr state = globalContext()->playbackState();
