@@ -20,8 +20,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef MU_ENGRAVING_TEXTBASE_H
-#define MU_ENGRAVING_TEXTBASE_H
+#pragma once
 
 #include <variant>
 
@@ -32,7 +31,7 @@
 
 #include "engravingitem.h"
 #include "property.h"
-#include "types.h"
+#include "../types/types.h"
 
 namespace mu::engraving {
 class TextBase;
@@ -82,6 +81,7 @@ public:
     CharFormat() {}
     CharFormat(const CharFormat& cf) { *this = cf; }
     bool operator==(const CharFormat& cf) const;
+    bool operator!=(const CharFormat& cf) const { return !(*this == cf); }
     CharFormat& operator=(const CharFormat& cf);
 
     FontStyle style() const { return m_style; }
@@ -255,6 +255,7 @@ public:
     std::list<TextFragment>& fragments() { return m_fragments; }
     std::list<TextFragment> fragmentsWithoutEmpty();
     const Shape& shape() const { return m_shape; }
+    Shape& shape() { return m_shape; }
     const RectF& boundingRect() const { return m_shape.bbox(); }
     RectF boundingRect(int col1, int col2, const TextBase*) const;
     size_t columns() const;
@@ -279,6 +280,7 @@ public:
 
 private:
     void simplify();
+    double musicSymbolBaseLineAdjust(const TextBase* t, const TextFragment& f, const std::list<TextFragment>::iterator fi);
 
     std::list<TextFragment> m_fragments;
     double m_y = 0.0;
@@ -305,11 +307,12 @@ public:
 
     Text& operator=(const Text&) = delete;
 
-    virtual void drawEditMode(muse::draw::Painter* p, EditData& ed, double currentViewScaling) override;
-    static void drawTextWorkaround(muse::draw::Painter* p, muse::draw::Font& f, const PointF& pos, const String& text);
-
     Align align() const { return m_align; }
     void setAlign(Align a) { m_align = a; }
+    AlignH position() const { return m_position; }
+    void setPosition(AlignH val) { m_position = val; }
+
+    static void drawTextWorkaround(muse::draw::Painter* p, muse::draw::Font& f, const PointF& pos, const String& text);
 
     static String plainToXmlText(const String& s) { return s.toXmlEscaped(); }
     void setPlainText(const String& t) { setXmlText(plainToXmlText(t)); }
@@ -329,34 +332,29 @@ public:
     bool empty() const { return xmlText().isEmpty(); }
     void clear() { setXmlText(String()); }
 
-    FontStyle fontStyle() const;
-    String family() const;
-    double size() const;
+    virtual FontStyle fontStyle() const;
+    virtual String family() const;
+    virtual double size() const;
 
-    void setFontStyle(const FontStyle& val);
-    void setFamily(const String& val);
-    void setSize(const double& val);
+    virtual void setFontStyle(const FontStyle& val);
+    virtual void setFamily(const String& val);
+    virtual void setSize(const double& val);
 
     bool anchorToEndOfPrevious() const { return m_anchorToEndOfPrevious; }
     void setAnchorToEndOfPrevious(bool v) { m_anchorToEndOfPrevious = v; }
 
     bool hasParentSegment() const { return explicitParent() && parent()->isSegment(); }
-    virtual bool needStartEditingAfterSelecting() const override { return hasParentSegment(); }
     virtual bool allowTimeAnchor() const override { return hasParentSegment(); }
     virtual void startEdit(EditData&) override;
     virtual bool isEditAllowed(EditData&) const override;
-    virtual bool supportsNonTextualEdit() const;
     virtual bool edit(EditData&) override;
     virtual void editCut(EditData&) override;
     virtual void editCopy(EditData&) override;
     virtual void endEdit(EditData&) override;
-    virtual void editDrag(EditData&) override;
+    virtual RectF drag(EditData&) override;
     virtual void endDrag(EditData&) override;
     void movePosition(EditData&, TextCursor::MoveOperation);
 
-    virtual void undoMoveSegment(Segment* newSeg, Fraction tickDiff);
-    void checkMeasureBoundariesAndMoveIfNeed();
-
     bool deleteSelectedText(EditData&);
 
     void selectAll(TextCursor*);
@@ -428,6 +426,9 @@ public:
     static const String UNDEFINED_FONT_FAMILY;
     static const double UNDEFINED_FONT_SIZE;
 
+    static bool isSorted(size_t r1, size_t c1, size_t r2, size_t c2);
+    static void sort(size_t& r1, size_t& c1, size_t& r2, size_t& c2);
+
     bool bold() const { return fontStyle() & FontStyle::Bold; }
     bool italic() const { return fontStyle() & FontStyle::Italic; }
     bool underline() const { return fontStyle() & FontStyle::Underline; }
@@ -487,6 +488,7 @@ public:
     //! NOTE It can only be set for some types of text, see who has the setter.
     //! At the moment it's: Text, Jump, Marker
     bool layoutToParentWidth() const { return m_layoutToParentWidth; }
+    virtual bool positionSeparateFromAlignment() const { return false; }
 
     void setVoiceAssignment(VoiceAssignment v) { m_voiceAssignment = v; }
     VoiceAssignment voiceAssignment() const { return m_voiceAssignment; }
@@ -496,26 +498,18 @@ public:
     AutoOnOff centerBetweenStaves() const { return m_centerBetweenStaves; }
     void genText();
 
+    double symbolSize() const { return m_symbolSize; }
+    void setSymbolSize(double v) { m_symbolSize = v; }
+    inline bool hasSymbolSize() const { return isMarker() || isTempoText() || isSystemText() || isStaffText(); }
+
 protected:
     TextBase(const ElementType& type, EngravingItem* parent = 0, TextStyleType tid = TextStyleType::DEFAULT,
              ElementFlags = ElementFlag::NOTHING);
     TextBase(const ElementType& type, EngravingItem* parent, ElementFlags);
     TextBase(const TextBase&);
 
-    virtual void startEditTextual(EditData&);
-    virtual void startEditNonTextual(EditData&);
-    virtual bool editTextual(EditData&);
-    virtual bool editNonTextual(EditData&);
-    virtual void endEditNonTextual(EditData&);
-    virtual void endEditTextual(EditData&);
-    virtual bool isNonTextualEditAllowed(EditData&) const;
-    virtual bool isTextualEditAllowed(EditData&) const;
     bool nudge(const EditData& ed);
 
-    virtual bool moveSegment(const EditData&);
-    void moveSnappedItems(Segment* newSeg, Fraction tickDiff) const;
-    void shiftInitOffset(EditData& ed, const PointF& offsetShift);
-
     void insertSym(EditData& ed, SymId id);
     void prepareFormat(const String& token, TextCursor& cursor);
     bool prepareFormat(const String& token, CharFormat& format);
@@ -525,8 +519,6 @@ protected:
     bool m_layoutToParentWidth = false;
 
 private:
-
-    void drawSelection(muse::draw::Painter*, const RectF&) const;
     void insert(TextCursor*, char32_t code, LayoutData* ldata) const;
     String genText(const LayoutData* ldata) const;
 
@@ -537,6 +529,8 @@ private:
     static String getHtmlStartTag(double, double&, const String&, String&, FontStyle, VerticalAlignment);
     static String getHtmlEndTag(FontStyle, VerticalAlignment);
 
+    static void swap(size_t& r1, size_t& c1, size_t& r2, size_t& c2);
+
 #ifndef ENGRAVING_NO_ACCESSIBILITY
     AccessibleItemPtr createAccessible() override;
 #endif
@@ -547,6 +541,8 @@ private:
 
     Align m_align;
 
+    AlignH m_position = AlignH::LEFT;
+
     FrameType m_frameType = FrameType::NO_FRAME;
     double m_textLineSpacing = 1.0;
     Color m_bgColor;
@@ -566,6 +562,8 @@ private:
     int m_hexState = -1;
     bool m_primed = 0;
 
+    double m_symbolSize = 18.0;
+
     TextCursor* m_cursor = nullptr;
 
     VoiceAssignment m_voiceAssignment = VoiceAssignment::ALL_VOICE_IN_INSTRUMENT;
@@ -580,5 +578,3 @@ inline bool isTextNavigationKey(int key, KeyboardModifiers modifiers)
     return (key == Key_Space && modifiers != TextEditingControlModifier) || key == Key_Tab;
 }
 } // namespace mu::engraving
-
-#endif
