@@ -126,26 +126,16 @@ void LyricsLayout::layout(Lyrics* item, LayoutContext& ctx)
         }
     }
 
-    bool styleDidChange = false;
-    if (item->isEven() && (item->textStyleType() != TextStyleType::LYRICS_EVEN)) {
-        item->initTextStyleType(TextStyleType::LYRICS_EVEN, /* preserveDifferent */ true);
-        styleDidChange = true;
-    }
-    if (!item->isEven() && (item->textStyleType() != TextStyleType::LYRICS_ODD)) {
-        item->initTextStyleType(TextStyleType::LYRICS_ODD, /* preserveDifferent */ true);
-        styleDidChange = true;
-    }
-
-    if (styleDidChange) {
-        item->styleChanged();
-    }
-
     createOrRemoveLyricsLine(item, ctx);
 
     if (item->isMelisma() || hasNumber) {
         // use the melisma style alignment setting
         if (item->isStyled(Pid::ALIGN)) {
-            item->setAlign(ctx.conf().styleV(Sid::lyricsMelismaAlign).value<Align>());
+            if (ctx.conf().styleB(Sid::lyricsCenterDashedSyllables) && !(item->separator() && item->separator()->isEndMelisma())) {
+                item->setAlign(Align(AlignH::HCENTER, AlignV::BASELINE));
+            } else {
+                item->setAlign(ctx.conf().styleV(Sid::lyricsMelismaAlign).value<Align>());
+            }
         }
     } else {
         // use the text style alignment setting
@@ -367,6 +357,10 @@ void LyricsLayout::layoutDashes(LyricsLineSegment* item)
         dashCount = std::max(dashCount, 1);
     }
 
+    if (style.styleB(Sid::lyricsLimitDashCount)) {
+        dashCount = std::min(dashCount, style.styleI(Sid::lyricsMaxDashCount));
+    }
+
     if (curLength < dashMinLength && dashCount > 0) {
         double diff = dashMinLength - curLength;
         if (isDashOnFirstSyllable) {
@@ -467,9 +461,9 @@ void LyricsLayout::createOrRemoveLyricsLine(Lyrics* item, LayoutContext& ctx)
 
             endSegment = endChordSeg->nextCR(track, false);
 
-            if (!endSegment) {
+            if (!endSegment || endSegment->tick() > endChord->endTick()) {
                 endSegment = endChordSeg;
-                while (endSegment && endSegment->tick() < endChord->tick() + endChord->ticks()) {
+                while (endSegment && endSegment->tick() < endChord->endTick()) {
                     endSegment = endSegment->nextCR(muse::nidx, true);
                 }
             }
