@@ -471,10 +471,11 @@ Shape ParenthesisLayout::getParentShape(const EngravingItem* parent)
 
     const Note* note = toNote(parent);
     const Chord* chord = note->chord();
-    LedgerLine* ledger = (note->line() < -1 || note->line() > note->staff()->lines(note->tick())) && !chord->ledgerLines().empty()
-                         ? chord->ledgerLines().front() : nullptr;
-    if (ledger) {
-        parentShape.add(ledger->shape().translate(ledger->pos() - note->pos() - ledger->staffOffset()));
+
+    if ((note->line() < -1 || note->line() > note->staff()->lines(note->tick())) && !chord->ledgerLines().empty()) {
+        for (LedgerLine* ledger : chord->ledgerLines()) {
+            parentShape.add(ledger->shape().translate(ledger->pos() - note->pos() - ledger->staffOffset()));
+        }
     }
 
     return parentShape;
