@@ -22,23 +22,25 @@
 
 #include <gtest/gtest.h>
 
-#include "dom/breath.h"
-#include "dom/chord.h"
-#include "dom/chordline.h"
-#include "dom/dynamic.h"
-#include "dom/engravingitem.h"
-#include "dom/excerpt.h"
-#include "dom/factory.h"
-#include "dom/fingering.h"
-#include "dom/image.h"
-#include "dom/masterscore.h"
-#include "dom/measure.h"
-#include "dom/measurerepeat.h"
-#include "dom/note.h"
-#include "dom/part.h"
-#include "dom/segment.h"
-#include "dom/spanner.h"
-#include "dom/staff.h"
+#include "io/fileinfo.h"
+
+#include "engraving/dom/breath.h"
+#include "engraving/dom/chord.h"
+#include "engraving/dom/chordline.h"
+#include "engraving/dom/dynamic.h"
+#include "engraving/dom/engravingitem.h"
+#include "engraving/dom/excerpt.h"
+#include "engraving/dom/factory.h"
+#include "engraving/dom/fingering.h"
+#include "engraving/dom/image.h"
+#include "engraving/dom/masterscore.h"
+#include "engraving/dom/measure.h"
+#include "engraving/dom/measurerepeat.h"
+#include "engraving/dom/note.h"
+#include "engraving/dom/part.h"
+#include "engraving/dom/segment.h"
+#include "engraving/dom/spanner.h"
+#include "engraving/dom/staff.h"
 
 #include "utils/scorerw.h"
 #include "utils/scorecomp.h"
@@ -172,9 +174,21 @@ void Engraving_PartsTests::testPartCreation(const String& test)
 {
     MasterScore* score = ScoreRW::readScore(PARTS_DATA_DIR + test + u".mscx");
     ASSERT_TRUE(score);
-    EXPECT_TRUE(ScoreComp::saveCompareScore(score, test + u"-1.mscx", PARTS_DATA_DIR + test + u".mscx"));
+
+    if (muse::io::FileInfo(ScoreRW::rootPath() + u"/" + PARTS_DATA_DIR + test + u"-ref.mscx").exists()) {
+        EXPECT_TRUE(ScoreComp::saveCompareScore(score, test + u"-1.mscx", PARTS_DATA_DIR + test + u"-ref.mscx"));
+    } else {
+        EXPECT_TRUE(ScoreComp::saveCompareScore(score, test + u"-1.mscx", PARTS_DATA_DIR + test + u".mscx"));
+    }
+
     TestUtils::createParts(score, 2);
-    EXPECT_TRUE(ScoreComp::saveCompareScore(score, test + u"-parts.mscx", PARTS_DATA_DIR + test + u"-parts.mscx"));
+
+    if (muse::io::FileInfo(ScoreRW::rootPath() + u"/" + PARTS_DATA_DIR + test + u"-parts-ref.mscx").exists()) {
+        EXPECT_TRUE(ScoreComp::saveCompareScore(score, test + u"-parts.mscx", PARTS_DATA_DIR + test + u"-parts-ref.mscx"));
+    } else {
+        EXPECT_TRUE(ScoreComp::saveCompareScore(score, test + u"-parts.mscx", PARTS_DATA_DIR + test + u"-parts.mscx"));
+    }
+
     delete score;
 }
 
@@ -1008,7 +1022,7 @@ MasterScore* Engraving_PartsTests::doAddImage()
     Note* note   = chord->upNote();
     EditData dd(0);
     Image* b = Factory::createImage(note);
-    b->load(PARTS_DATA_DIR + u"schnee.png");
+    b->loadFromFile(PARTS_DATA_DIR + u"schnee.png");
     dd.dropElement = b;
 
     score->startCmd(TranslatableString::untranslatable("Engraving parts tests"));
