@@ -191,6 +191,11 @@ bool DockBase::separatorsVisible() const
     return m_properties.separatorsVisible;
 }
 
+bool DockBase::defaultVisibility() const
+{
+    return m_defaultVisibility;
+}
+
 bool DockBase::isCompact() const
 {
     return m_isCompact;
@@ -449,8 +454,8 @@ void DockBase::open()
         return;
     }
 
-    m_dockWidget->show();
     setVisible(true);
+    m_dockWidget->show();
 
     applySizeConstraints();
 }
@@ -629,12 +634,18 @@ void DockBase::componentComplete()
     connect(m_dockWidget, &KDDockWidgets::DockWidgetQuick::widthChanged, this, [this]() {
         if (m_dockWidget) {
             setWidth(m_dockWidget->width());
+            if (inited()) {
+                applySizeConstraints();
+            }
         }
     });
 
     connect(m_dockWidget, &KDDockWidgets::DockWidgetQuick::heightChanged, this, [this]() {
         if (m_dockWidget) {
             setHeight(m_dockWidget->height());
+            if (inited()) {
+                applySizeConstraints();
+            }
         }
     });
 
@@ -683,14 +694,13 @@ void DockBase::applySizeConstraints()
         window->setMinimumSize(minimumSize);
         window->setMaximumSize(maximumSize);
 
-        QSize winSize = adjustSizeByConstraints(window->frameGeometry().size(), minimumSize, maximumSize);
-        QRect winRect(window->dragRect().topLeft(), winSize);
-
+        const QSize winSize = adjustSizeByConstraints(window->frameGeometry().size(), minimumSize, maximumSize);
+#ifdef Q_OS_MACOS
+        window->setWidth(winSize.width());
+        window->setHeight(winSize.height());
+#endif
+        const QRect winRect(window->dragRect().topLeft(), winSize);
         window->setGeometry(winRect);
-
-        if (KDDockWidgets::LayoutWidget* layout = window->layoutWidget()) {
-            layout->setLayoutSize(winSize);
-        }
     }
 
     if (!frame || !m_inited) {
