@@ -19,8 +19,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
-#ifndef MUSE_GLOBAL_INTERACTIVE_H
-#define MUSE_GLOBAL_INTERACTIVE_H
+
+#pragma once
 
 #include "async/asyncable.h"
 
@@ -90,7 +90,7 @@ public:
     io::paths_t selectMultipleDirectories(const std::string& title, const io::path_t& dir, const io::paths_t& selectedDirectories) override;
 
     // color
-    async::Promise<Color> selectColor(const Color& color = Color::WHITE, const std::string& title = "") override;
+    async::Promise<Color> selectColor(const Color& color = Color::WHITE, const std::string& title = {}, bool allowAlpha = false) override;
     bool isSelectColorOpened() const override;
 
     // custom
@@ -133,5 +133,3 @@ private:
                                           const ButtonDatas& buttons, int defBtn, const Options& options, const std::string& dialogTitle);
 };
 }
-
-#endif // MUSE_GLOBAL_UIINTERACTIVE_H
