@@ -64,7 +64,7 @@ public:
     MOCK_METHOD(io::path_t, selectDirectory, (const std::string&, const io::path_t&), (override));
     MOCK_METHOD(io::paths_t, selectMultipleDirectories, (const std::string&, const io::path_t&, const io::paths_t&), (override));
 
-    MOCK_METHOD(async::Promise<Color>, selectColor, (const Color&, const std::string&), (override));
+    MOCK_METHOD(async::Promise<Color>, selectColor, (const Color&, const std::string&, bool), (override));
     MOCK_METHOD(bool, isSelectColorOpened, (), (const, override));
 
     MOCK_METHOD(RetVal<Val>, openSync, (const UriQuery&), (override));
