@@ -63,6 +63,7 @@ enum class SoundId
     Theorbo,
     Archlute,
     Balalaika,
+    Guzheng,
     Koto,
     Oud,
     Shamisen,
@@ -87,6 +88,7 @@ enum class SoundId
     Erhu,
     Contrabass,
     Octobass,
+    TimpleCanario,
 
     WindsGroup,
     Piccolo,
@@ -182,8 +184,34 @@ enum class SoundId
     KlaxonHorns,
     Kalimba,
     Bongos,
+    Xiaogu,
+    Bangu,
+    Dagu,
+    Daluo,
+    Xiaoluo,
+    Ban,
+    Dabo,
+    Naobo,
+    Bangzi,
+    Janggu,
+    Buk,
+    Sogo,
+    Kkwaenggwari,
+    Jing,
     TomToms,
+    KoTsuzumi,
+    OTsuzumi,
+    Kakko,
+    ShimeDaiko,
+    MiyaDaiko,
+    TsuriDaiko,
+    OkedoDaiko,
+    Kane,
+    Shoko,
     Conga,
+    Djembe,
+    Doumbek,
+    Cajon,
     Cuica,
     Drumset,
     Drum,
@@ -209,11 +237,14 @@ enum class SoundId
     Quijada,
     Ratchet,
     Shaker,
+    Shekere,
     Stones,
     Tambourine,
     Tubo,
     Vibraslap,
     Whip,
+    Cannon,
+    BirdCall,
     Snap,
     Clap,
     Slap,
@@ -295,7 +326,11 @@ enum class SoundSubCategory
     Ride,
     Sleigh,
     Cow,
+    Agogo,
     Marching,
+    Show_Style,
+    Opera,
+    China,
 
     Splash,
     Crash,
@@ -303,6 +338,8 @@ enum class SoundSubCategory
     Bowl,
     Frame,
     Slit,
+    Log,
+    Ocean,
     Field,
     Snare,
     Brake,
@@ -437,6 +474,7 @@ inline const std::unordered_map<SoundId, String> ID_STRINGS
     { SoundId::Theorbo, String(u"theorbo") },
     { SoundId::Archlute, String(u"archlute") },
     { SoundId::Balalaika, String(u"balalaika") },
+    { SoundId::Guzheng, String(u"ghuzheng") },
     { SoundId::Koto, String(u"koto") },
     { SoundId::Oud, String(u"oud") },
     { SoundId::Shamisen, String(u"shamisen") },
@@ -461,6 +499,7 @@ inline const std::unordered_map<SoundId, String> ID_STRINGS
     { SoundId::Erhu, String(u"erhu") },
     { SoundId::Contrabass, String(u"contrabass") },
     { SoundId::Octobass, String(u"octobass") },
+    { SoundId::TimpleCanario, String(u"timple_canario") },
 
     { SoundId::WindsGroup, String(u"winds_group") },
     { SoundId::Piccolo, String(u"piccolo") },
@@ -556,8 +595,34 @@ inline const std::unordered_map<SoundId, String> ID_STRINGS
     { SoundId::KlaxonHorns, String(u"klaxon_horns") },
     { SoundId::Kalimba, String(u"kalimba") },
     { SoundId::Bongos, String(u"bongos") },
+    { SoundId::Xiaogu, String(u"xiaogu") },
+    { SoundId::Bangu, String(u"bangu") },
+    { SoundId::Dagu, String(u"dagu") },
+    { SoundId::Daluo, String(u"daluo") },
+    { SoundId::Xiaoluo, String(u"xiaoluo") },
+    { SoundId::Ban, String(u"ban") },
+    { SoundId::Dabo, String(u"dabo") },
+    { SoundId::Naobo, String(u"naobo") },
+    { SoundId::Bangzi, String(u"bangzi") },
+    { SoundId::Janggu, String(u"janggu") },
+    { SoundId::Buk, String(u"buk") },
+    { SoundId::Sogo, String(u"sogo") },
+    { SoundId::Kkwaenggwari, String(u"kkwaenggwari") },
+    { SoundId::Jing, String(u"jing") },
     { SoundId::TomToms, String(u"tom_toms") },
+    { SoundId::KoTsuzumi, String(u"ko_tsuzumi") },
+    { SoundId::OTsuzumi, String(u"o_tsuzumi") },
+    { SoundId::Kakko, String(u"kakko") },
+    { SoundId::ShimeDaiko, String(u"shime_daiko") },
+    { SoundId::MiyaDaiko, String(u"miya_daiko") },
+    { SoundId::TsuriDaiko, String(u"tsuri_daiko") },
+    { SoundId::OkedoDaiko, String(u"okedo_daiko") },
+    { SoundId::Kane, String(u"kane") },
+    { SoundId::Shoko, String(u"shoko") },
     { SoundId::Conga, String(u"conga") },
+    { SoundId::Djembe, String(u"djembe") },
+    { SoundId::Doumbek, String(u"doumbek") },
+    { SoundId::Cajon, String(u"cajon") },
     { SoundId::Cuica, String(u"cuica") },
     { SoundId::Drumset, String(u"drumset") },
     { SoundId::Drum, String(u"drum") },
@@ -583,11 +648,14 @@ inline const std::unordered_map<SoundId, String> ID_STRINGS
     { SoundId::Quijada, String(u"quijada") },
     { SoundId::Ratchet, String(u"ratchet") },
     { SoundId::Shaker, String(u"shaker") },
+    { SoundId::Shekere, String(u"shekere") },
     { SoundId::Stones, String(u"stones") },
     { SoundId::Tambourine, String(u"tambourine") },
     { SoundId::Tubo, String(u"tubo") },
     { SoundId::Vibraslap, String(u"vibraslap") },
     { SoundId::Whip, String(u"whip") },
+    { SoundId::Cannon, String(u"cannon") },
+    { SoundId::BirdCall, String(u"bird_call") },
     { SoundId::Snap, String(u"snap") },
     { SoundId::Clap, String(u"clap") },
     { SoundId::Slap, String(u"slap") },
@@ -716,7 +784,11 @@ inline const std::unordered_map<SoundSubCategory, String> SUBCATEGORY_STRINGS
     { SoundSubCategory::Ride, String(u"ride") },
     { SoundSubCategory::Sleigh, String(u"sleigh") },
     { SoundSubCategory::Cow, String(u"cow") },
+    { SoundSubCategory::Agogo, String(u"agogo") },
     { SoundSubCategory::Marching, String(u"marching") },
+    { SoundSubCategory::Show_Style, String(u"show_style") },
+    { SoundSubCategory::Opera, String(u"opera") },
+    { SoundSubCategory::China, String(u"china") },
 
     { SoundSubCategory::Splash, String(u"splash") },
     { SoundSubCategory::Crash, String(u"crash") },
@@ -724,6 +796,8 @@ inline const std::unordered_map<SoundSubCategory, String> SUBCATEGORY_STRINGS
     { SoundSubCategory::Bowl, String(u"bowl") },
     { SoundSubCategory::Frame, String(u"frame") },
     { SoundSubCategory::Slit, String(u"slit") },
+    { SoundSubCategory::Log, String(u"log") },
+    { SoundSubCategory::Ocean, String(u"ocean") },
     { SoundSubCategory::Field, String(u"field") },
     { SoundSubCategory::Snare, String(u"snare") },
     { SoundSubCategory::Brake, String(u"brake") },
