@@ -35,7 +35,7 @@ using namespace muse::mi;
 using namespace muse::ipc;
 using namespace muse::actions;
 
-static const muse::UriQuery DEV_SHOW_INFO_URI("muse://devtools/multiinstances/info?sync=false&modal=false");
+static const muse::UriQuery DEV_SHOW_INFO_URI("muse://devtools/multiinstances/info?modal=false");
 static const QString METHOD_PROJECT_IS_OPENED("PROJECT_IS_OPENED");
 static const QString METHOD_ACTIVATE_WINDOW_WITH_PROJECT("ACTIVATE_WINDOW_WITH_PROJECT");
 static const QString METHOD_IS_WITHOUT_PROJECT("IS_WITHOUT_PROJECT");
@@ -52,7 +52,7 @@ static const QString METHOD_SETTINGS_SET_VALUE("SETTINGS_SET_VALUE");
 static const QString METHOD_QUIT("METHOD_QUIT");
 static const QString METHOD_QUIT_WITH_RESTART_LAST_INSTANCE("METHOD_QUIT_WITH_RESTART_LAST_INSTANCE");
 static const QString METHOD_QUIT_WITH_RUNING_INSTALLATION("METHOD_QUIT_WITH_RUNING_INSTALLATION");
-static const QString METHOD_QUITED("METHOD_QUITED");
+static const QString METHOD_INSTANCE_CLOSED("INSTANCE_CLOSED");
 static const QString METHOD_RESOURCE_CHANGED("RESOURCE_CHANGED");
 
 MultiInstancesProvider::~MultiInstancesProvider()
@@ -85,7 +85,7 @@ bool MultiInstancesProvider::isInited() const
 
 void MultiInstancesProvider::onMsg(const Msg& msg)
 {
-    LOGI() << msg.method;
+    LOGI() << msg.method << ", me: " << m_selfID << ", msg src: " << msg.srcID << ", msg dest: " << msg.destID;
 
 #define CHECK_ARGS_COUNT(c) IF_ASSERT_FAILED(msg.args.count() >= c) { return; }
 
@@ -165,8 +165,8 @@ void MultiInstancesProvider::onMsg(const Msg& msg)
     } else if (msg.method == METHOD_QUIT_WITH_RUNING_INSTALLATION) {
         CHECK_ARGS_COUNT(1);
         dispatcher()->dispatch("quit", ActionData::make_arg2<bool, std::string>(false, msg.args.at(0).toStdString()));
-    } else if (msg.method == METHOD_QUITED) {
-        m_ipcChannel->response(METHOD_QUITED, { }, msg.srcID);
+    } else if (msg.method == METHOD_INSTANCE_CLOSED && msg.type == ipc::MsgType::Request) {
+        m_ipcChannel->response(METHOD_INSTANCE_CLOSED, { }, msg.srcID);
     } else if (msg.method == METHOD_RESOURCE_CHANGED) {
         resourceChanged().send(msg.args.at(0).toStdString());
     }
@@ -458,7 +458,7 @@ void MultiInstancesProvider::notifyAboutInstanceWasQuited()
         return;
     }
 
-    m_ipcChannel->broadcast(METHOD_QUITED);
+    m_ipcChannel->broadcast(METHOD_INSTANCE_CLOSED);
 }
 
 void MultiInstancesProvider::quitForAll()
