@@ -79,7 +79,27 @@ void InteractiveProvider::raiseWindowInStack(QObject* newActiveWindow)
     }
 }
 
-async::Promise<Color> InteractiveProvider::selectColor(const Color& color, const std::string& title)
+static std::vector<QColor> getCustomColors()
+{
+    const int customColorCount = QColorDialog::customCount();
+    std::vector<QColor> customColors;
+    customColors.reserve(customColorCount);
+    for (int i = 0; i < customColorCount; ++i) {
+        customColors.push_back(QColorDialog::customColor(i));
+    }
+
+    return customColors;
+}
+
+static void setCustomColors(const std::vector<QColor>& customColors)
+{
+    const int customColorCount = std::min(QColorDialog::customCount(), static_cast<int>(customColors.size()));
+    for (int i = 0; i < customColorCount; ++i) {
+        QColorDialog::setCustomColor(i, customColors[i]);
+    }
+}
+
+async::Promise<Color> InteractiveProvider::selectColor(const Color& color, const std::string& title, bool allowAlpha)
 {
     if (m_isSelectColorOpened) {
         LOGW() << "already opened";
@@ -91,7 +111,9 @@ async::Promise<Color> InteractiveProvider::selectColor(const Color& color, const
 
     m_isSelectColorOpened = true;
 
-    return async::make_promise<Color>([this, color, title](auto resolve, auto reject) {
+    setCustomColors(config()->colorDialogCustomColors());
+
+    return async::make_promise<Color>([this, color, title, allowAlpha](auto resolve, auto reject) {
         //! FIX https://github.com/musescore/MuseScore/issues/23208
         shortcutsRegister()->setActive(false);
 
@@ -100,11 +122,21 @@ async::Promise<Color> InteractiveProvider::selectColor(const Color& color, const
             dlg->setWindowTitle(QString::fromStdString(title));
         }
 
-        dlg->setCurrentColor(color.toQColor());
+        QColor currentColor = color.toQColor();
+
+        // If the color is fully transparent, set alpha to opaque, to avoid "Hm, nothing happened" user confusion
+        if (currentColor.alpha() == 0) {
+            currentColor.setAlpha(255);
+        }
+
+        dlg->setCurrentColor(currentColor);
+        dlg->setOption(QColorDialog::ShowAlphaChannel, allowAlpha);
 
         QObject::connect(dlg, &QColorDialog::finished, [this, dlg, resolve, reject](int result) {
             dlg->deleteLater();
 
+            config()->setColorDialogCustomColors(getCustomColors());
+
             m_isSelectColorOpened = false;
             shortcutsRegister()->setActive(true);
 
@@ -129,7 +161,7 @@ bool InteractiveProvider::isSelectColorOpened() const
     return m_isSelectColorOpened;
 }
 
-RetVal<Val> InteractiveProvider::openSync(const UriQuery& q_)
+RetVal<Val> InteractiveProvider::openSync(const UriQuery& q)
 {
 #ifndef MUSE_MODULE_UI_SYNCINTERACTIVE_SUPPORTED
     NOT_SUPPORTED;
@@ -141,11 +173,6 @@ RetVal<Val> InteractiveProvider::openSync(const UriQuery& q_)
     }
 #endif
 
-    UriQuery q = q_;
-
-    //! NOTE Disable Dialog.exec()
-    q.set("sync", false);
-
     RetVal<Val> rv;
     QEventLoop loop;
     Promise<Val>::Resolve resolve;
@@ -375,7 +402,6 @@ void InteractiveProvider::fillExtData(QmlLaunchData* data, const UriQuery& q, co
     }
 
     data->setValue("uri", QString::fromStdString(VIEWER_URI.toString()));
-    data->setValue("sync", params.value("sync", false));
     data->setValue("params", params);
 }
 
@@ -386,7 +412,6 @@ void InteractiveProvider::fillData(QmlLaunchData* data, const Uri& uri, const QV
     data->setValue("type", meta.type);
     data->setValue("uri", QString::fromStdString(uri.toString()));
     data->setValue("params", params);
-    data->setValue("sync", params.value("sync", false));
     data->setValue("modal", params.value("modal", ""));
 }
 
