@@ -25,30 +25,29 @@
 
 #include "bb.h"
 
-#include "engravingerrors.h"
-#include "engraving/dom/mscore.h"
-
+#include "engraving/dom/box.h"
+#include "engraving/dom/chord.h"
+#include "engraving/dom/chordlist.h"
+#include "engraving/dom/drumset.h"
 #include "engraving/dom/factory.h"
+#include "engraving/dom/harmony.h"
+#include "engraving/dom/key.h"
+#include "engraving/dom/keysig.h"
+#include "engraving/dom/layoutbreak.h"
 #include "engraving/dom/masterscore.h"
+#include "engraving/dom/measure.h"
+#include "engraving/dom/mscore.h"
+#include "engraving/dom/note.h"
 #include "engraving/dom/part.h"
+#include "engraving/dom/pitchspelling.h"
+#include "engraving/dom/rest.h"
+#include "engraving/dom/segment.h"
+#include "engraving/dom/slur.h"
 #include "engraving/dom/staff.h"
 #include "engraving/dom/text.h"
-#include "engraving/dom/box.h"
-#include "engraving/dom/slur.h"
 #include "engraving/dom/tie.h"
-#include "engraving/dom/note.h"
-#include "engraving/dom/chord.h"
-#include "engraving/dom/rest.h"
-#include "engraving/dom/drumset.h"
 #include "engraving/dom/utils.h"
-#include "engraving/dom/chordlist.h"
-#include "engraving/dom/harmony.h"
-#include "engraving/dom/layoutbreak.h"
-#include "engraving/dom/key.h"
-#include "engraving/dom/pitchspelling.h"
-#include "engraving/dom/measure.h"
-#include "engraving/dom/segment.h"
-#include "engraving/dom/keysig.h"
+#include "engraving/engravingerrors.h"
 
 #include "log.h"
 
@@ -405,7 +404,7 @@ Err importBB(MasterScore* score, const QString& name)
         return engraving::Err::FileOpenError;
     }
     score->style().set(Sid::chordsXmlFile, true);
-    score->chordList()->read(score->configuration()->appDataPath(), u"chords.xml");
+    score->chordList()->read(u"chords.xml");
     *(score->sigmap()) = bb.siglist();
 
     QList<BBTrack*>* tracks = bb.tracks();
@@ -431,7 +430,7 @@ Err importBB(MasterScore* score, const QString& name)
         Fraction ts = score->sigmap()->timesig(tick.ticks()).timesig();
         measure->setTimesig(ts);
         measure->setTicks(ts);
-        score->measures()->add(measure);
+        score->measures()->append(measure);
     }
 
     //---------------------------------------------------
@@ -489,7 +488,7 @@ Err importBB(MasterScore* score, const QString& name)
     if (measureB->type() != ElementType::VBOX) {
         measureB = Factory::createTitleVBox(score->dummy()->system());
         measureB->setNext(score->first());
-        score->measures()->add(measureB);
+        score->measures()->append(measureB);
     }
     measureB->add(text);
 
@@ -511,16 +510,17 @@ Err importBB(MasterScore* score, const QString& name)
         }
         Segment* s = m->getSegment(SegmentType::ChordRest, tick);
         Harmony* h = Factory::createHarmony(s);
+        HarmonyInfo* info = new HarmonyInfo(score);
         h->setTrack(0);
-        h->setRootTpc(table[c.root - 1]);
+        info->setRootTpc(table[c.root - 1]);
         if (c.bass > 0) {
-            h->setBaseTpc(table[c.bass - 1]);
+            info->setBassTpc(table[c.bass - 1]);
         } else {
-            h->setBaseTpc(Tpc::TPC_INVALID);
+            info->setBassTpc(Tpc::TPC_INVALID);
         }
-        h->setId(c.extension);
-        h->getDescription();
-        h->render();
+        info->setId(c.extension);
+        h->addChord(info);
+
         s->add(h);
     }
 
