@@ -29,7 +29,7 @@
 #include "symbols.h"
 
 namespace Bww {
-static const char* symTable[] =
+static constexpr const char* symTable[] =
 {
     "COMMENT",
     "HEADER",
@@ -51,13 +51,10 @@ static const char* symTable[] =
 
 QString symbolToString(Symbol s)
 {
-    if (s < 0) {
+    if (static_cast<size_t>(s) >= sizeof symTable) {
         return "INVALID";
     }
-    if (static_cast<unsigned>(s) > sizeof symTable) {
-        return "INVALID";
-    } else {
-        return symTable[s];
-    }
+
+    return symTable[s];
 }
 } // namespace Bww
