@@ -19,21 +19,20 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
-#ifndef IMPORTMIDI_LRHAND_H
-#define IMPORTMIDI_LRHAND_H
+#pragma once
 
 #include <map>
 
+#include "internal/midishared/generalmidi.h"
+
 namespace mu::iex::midi {
 class MTrack;
 class MidiChord;
 class ReducedFraction;
 
 namespace LRHand {
-bool needToSplit(const std::multimap<ReducedFraction, MidiChord>& chords, int midiProgram, bool isDrumTrack);
+bool needToSplit(const std::multimap<ReducedFraction, MidiChord>& chords, GM1Program, bool isDrumTrack);
 
 void splitIntoLeftRightHands(std::multimap<int, MTrack>& tracks);
 } // namespace LRHand
 } // namespace mu::iex::midi
-
-#endif // IMPORTMIDI_LRHAND_H
