@@ -21,6 +21,8 @@
  */
 #include "notationviewinputcontroller.h"
 
+#include <set>
+
 #include <QApplication>
 #include <QMimeData>
 #include <QQuickItem>
@@ -50,7 +52,7 @@ static bool seekAllowed(const mu::engraving::EngravingItem* element)
         return false;
     }
 
-    static const ElementTypeSet playableTypes = {
+    static const ElementTypeSet ALLOWED_TYPES {
         ElementType::NOTE,
         ElementType::REST,
         ElementType::MMREST,
@@ -58,7 +60,7 @@ static bool seekAllowed(const mu::engraving::EngravingItem* element)
         ElementType::BAR_LINE
     };
 
-    return muse::contains(playableTypes, element->type());
+    return muse::contains(ALLOWED_TYPES, element->type());
 }
 
 NotationViewInputController::NotationViewInputController(IControlledView* view, const muse::modularity::ContextPtr& iocCtx)
@@ -147,10 +149,62 @@ void NotationViewInputController::onNotationChanged()
         m_view->hideContextMenu();
         m_view->hideElementPopup();
 
-        if (AbstractElementPopupModel::supportsPopup(selectedItem)) {
-            m_view->showElementPopup(type, selectedItem->canvasBoundingRect());
+        if (AbstractElementPopupModel::hasElementEditPopup(selectedItem)) {
+            m_view->showElementPopup(type);
         }
     });
+
+    currNotation->interaction()->textEditingStarted().onNotify(this, [this] {
+        const INotationPtr notation = currentNotation();
+        if (!notation) {
+            return;
+        }
+
+        m_view->hideContextMenu();
+
+        const TextBase* item = notation->interaction()->editedText();
+        if (AbstractElementPopupModel::hasTextStylePopup(item)) {
+            static const std::set<ElementType> TYPES_NEEDING_STAFF {
+                ElementType::LYRICS,
+                ElementType::FINGERING,
+                ElementType::STICKING,
+                ElementType::HARMONY,
+                ElementType::FIGURED_BASS
+            };
+            const bool needToSeeStaffWhileEnteringText = muse::contains(TYPES_NEEDING_STAFF, item->type());
+            if (!needToSeeStaffWhileEnteringText || !item->empty()) {
+                m_view->showElementPopup(item->type());
+                return;
+            }
+        }
+
+        if (item->isDynamic()) {
+            m_view->showElementPopup(item->type());
+            return;
+        }
+
+        m_view->hideElementPopup();
+    });
+
+    currNotation->interaction()->textEditingChanged().onNotify(this, [this] {
+        const INotationPtr notation = currentNotation();
+        if (!notation) {
+            return;
+        }
+
+        if (!notation->interaction()->isTextEditingStarted()) {
+            return;
+        }
+
+        const TextBase* item = notation->interaction()->editedText();
+        if (AbstractElementPopupModel::hasTextStylePopup(item) && item->cursor()->hasSelection()) {
+            m_view->showElementPopup(item->type());
+        }
+    });
+
+    currNotation->interaction()->textEditingEnded().onReceive(this, [this](const TextBase*) {
+        m_view->hideElementPopup(PopupModelType::TYPE_TEXT);
+    });
 }
 
 void NotationViewInputController::initZoom()
@@ -596,8 +650,7 @@ void NotationViewInputController::wheelEvent(QWheelEvent* event)
 
 void NotationViewInputController::mousePressEvent(QMouseEvent* event)
 {
-    PointF logicPos = PointF(m_view->toLogical(event->pos()));
-    Qt::KeyboardModifiers keyState = event->modifiers();
+    PointF logicPos = m_view->toLogical(event->pos());
     Qt::MouseButton button = event->button();
 
     m_mouseDownInfo = {
@@ -606,6 +659,9 @@ void NotationViewInputController::mousePressEvent(QMouseEvent* event)
         /*.logicalBeginPoint =*/ logicPos
     };
 
+    m_shouldStartEditOnLeftClickRelease = false;
+    m_ignoreNextMouseContextMenuEvent = false;
+
     // When using MiddleButton, just start moving the canvas
     if (button == Qt::MiddleButton) {
         return;
@@ -622,8 +678,6 @@ void NotationViewInputController::mousePressEvent(QMouseEvent* event)
     };
 
     if (!m_readonly) {
-        m_prevHitElement = hitElementContext().element;
-
         INotationInteraction::HitElementContext context;
         context.element = viewInteraction()->hitElement(logicPos, hitWidth());
         context.staff = viewInteraction()->hitStaff(logicPos);
@@ -635,17 +689,11 @@ void NotationViewInputController::mousePressEvent(QMouseEvent* event)
 
     // note enter mode
     if (m_view->isNoteEnterMode()) {
-        if (button == Qt::RightButton) {
-            dispatcher()->dispatch("remove-note", ActionData::make_arg1<PointF>(logicPos));
-            return;
-        }
-
-        bool replace = keyState & Qt::ShiftModifier;
-        bool insert = keyState & Qt::ControlModifier;
-        dispatcher()->dispatch("put-note", ActionData::make_arg3<PointF, bool, bool>(logicPos, replace, insert));
+        handleClickInNoteInputMode(event);
         return;
     }
 
+    // triple click
     if (m_tripleClickPending) {
         if (viewInteraction()->isTextEditingStarted()) {
             viewInteraction()->selectText(mu::engraving::SelectTextType::All);
@@ -657,22 +705,6 @@ void NotationViewInputController::mousePressEvent(QMouseEvent* event)
         return;
     }
 
-    if (keyState == (Qt::ShiftModifier | Qt::ControlModifier)) {
-        m_mouseDownInfo.dragAction = viewInteraction()->isOutgoingDragElementAllowed(hitElement)
-                                     ? MouseDownInfo::DragOutgoingElement
-                                     : MouseDownInfo::Nothing;
-        return;
-    }
-
-    if (button == Qt::LeftButton && (!hitElement || hitElement->isMeasure())) {
-        INotationSelectionPtr selection = viewInteraction()->selection();
-
-        if (selection->isRange() && selection->range()->containsPoint(logicPos)) {
-            m_mouseDownInfo.dragAction = MouseDownInfo::DragOutgoingRange;
-            return;
-        }
-    }
-
     ClickContext ctx;
     ctx.logicClickPos = logicPos;
     ctx.hitElement = hitElement;
@@ -680,56 +712,39 @@ void NotationViewInputController::mousePressEvent(QMouseEvent* event)
     ctx.isHitGrip = viewInteraction()->isHitGrip(logicPos);
     ctx.event = event;
 
-    m_shouldTogglePopupOnLeftClickRelease = hitElement && hitElement->selected();
-
-    if (needSelect(ctx)) {
-        SelectType selectType = SelectType::SINGLE;
-        if (keyState == Qt::NoModifier) {
-            selectType = SelectType::SINGLE;
-        } else if (keyState & Qt::ShiftModifier) {
-            selectType = SelectType::RANGE;
-        } else if (keyState & Qt::ControlModifier) {
-            selectType = SelectType::ADD;
-        }
-
-        std::vector<EngravingItem*> hitElements = viewInteraction()->hitElements(ctx.logicClickPos, hitWidth());
-        size_t numHitElements = hitElements.size();
-
-        // overlapping elements with ctrl modifier
-        if (numHitElements > 1 && (keyState & Qt::ControlModifier)) {
-            size_t currTop = numHitElements - 1;
-            EngravingItem* e = hitElements[currTop];
-            std::set<EngravingItem*> selectedAtPosition;
-            bool found = false;
-
-            // e is the topmost element in stacking order,
-            // but we want to replace it with "first non-measure element after a selected element"
-            // (if such an element exists)
-            for (size_t i = 0; i <= numHitElements; ++i) {
-                if (found) {
-                    e = hitElements[currTop];
-                    if (!e->isMeasure()) {
-                        break;
-                    }
-                } else if (hitElements[currTop]->selected()) {
-                    found = true;
-                    selectedAtPosition.emplace(hitElements[currTop]);
-                    e = nullptr;
-                }
-                currTop = (currTop + 1) % numHitElements;
-            }
-
-            if (e && !e->selected()) {
-                for (EngravingItem* selectedElem : selectedAtPosition) {
-                    selectedElem->score()->deselect(selectedElem);
-                }
-                viewInteraction()->select({ e }, SelectType::ADD, hitStaffIndex);
-            }
-        } else {
-            viewInteraction()->select({ hitElement }, selectType, hitStaffIndex);
-        }
+    // Grip
+    bool consumed = mousePress_considerGrip(ctx);
+    if (consumed) {
+        return;
     }
 
+    // End editing
+    if (!ctx.hitElement) {
+        viewInteraction()->endEditElement();
+    }
+
+    // Drag outgoing: element
+    consumed = mousePress_considerDragOutgoingElement(ctx);
+    if (consumed) {
+        return;
+    }
+
+    // Drag outgoing: range
+    consumed = mousePress_considerDragOutgoingRange(ctx);
+    if (consumed) {
+        return;
+    }
+
+    // Alt+click to paste range
+    consumed = mousePress_considerStartPasteRangeOnRelease(ctx);
+    if (consumed) {
+        return;
+    }
+
+    // Select
+    mousePress_considerSelect(ctx);
+
+    // Misc
     if (button == Qt::LeftButton) {
         handleLeftClick(ctx);
     } else if (button == Qt::RightButton) {
@@ -737,26 +752,176 @@ void NotationViewInputController::mousePressEvent(QMouseEvent* event)
     }
 }
 
-bool NotationViewInputController::needSelect(const ClickContext& ctx) const
+void NotationViewInputController::handleClickInNoteInputMode(QMouseEvent* event)
+{
+    const PointF logicPos = m_view->toLogical(event->pos());
+
+    if (event->button() == Qt::RightButton) {
+        m_ignoreNextMouseContextMenuEvent = true;
+        dispatcher()->dispatch("remove-note", ActionData::make_arg1<PointF>(logicPos));
+        return;
+    }
+
+    const Qt::KeyboardModifiers keyState = event->modifiers();
+    const bool replace = keyState & Qt::ShiftModifier;
+    const bool insert = keyState & Qt::ControlModifier;
+    dispatcher()->dispatch("put-note", ActionData::make_arg3<PointF, bool, bool>(logicPos, replace, insert));
+}
+
+bool NotationViewInputController::mousePress_considerGrip(const ClickContext& ctx)
 {
     if (ctx.isHitGrip && ctx.event->button() == Qt::LeftButton) {
+        viewInteraction()->startEditGrip(ctx.logicClickPos);
+        return true;
+    } else if (viewInteraction()->isGripEditStarted()) {
+        viewInteraction()->endEditGrip();
+    }
+
+    return false;
+}
+
+bool NotationViewInputController::mousePress_considerDragOutgoingElement(const ClickContext& ctx)
+{
+    if (ctx.event->button() != Qt::LeftButton
+        || ctx.event->modifiers() != (Qt::ShiftModifier | Qt::ControlModifier)) {
         return false;
     }
 
+    if (!ctx.hitElement || !viewInteraction()->isOutgoingDragElementAllowed(ctx.hitElement)) {
+        return false;
+    }
+
+    viewInteraction()->select({ ctx.hitElement }, SelectType::SINGLE, ctx.hitStaff);
+    m_mouseDownInfo.dragAction = MouseDownInfo::DragOutgoingElement;
+    return true;
+}
+
+bool NotationViewInputController::mousePress_considerStartPasteRangeOnRelease(const ClickContext& ctx)
+{
+    // Check if this is a left click with Alt modifier
+    if (ctx.event->button() != Qt::LeftButton || !(ctx.event->modifiers() & Qt::AltModifier)) {
+        return false;
+    }
+
+    // Check if we have a range selection that can be copied
+    const INotationSelectionPtr selection = viewInteraction()->selection();
+    if (!selection->isRange() || !selection->canCopy()) {
+        return false;
+    }
+
+    const INotationSelectionRangePtr range = selection->range();
+    const Fraction sourceTick = range->startTick();
+    const Fraction tickLength = range->endTick() - range->startTick();
+    const engraving::staff_idx_t sourceStaffIdx = range->startStaffIndex();
+    const size_t numStaves = range->endStaffIndex() - range->startStaffIndex();
+
+    const bool started = viewInteraction()->startDropRange(sourceTick, tickLength, sourceStaffIdx, numStaves,
+                                                           /*preserveMeasureAlignment=*/ true);
+    if (!started) {
+        return false;
+    }
+
+    m_mouseDownInfo.dragAction = MouseDownInfo::PasteRangeOnRelease;
+
+    const bool canDrop = viewInteraction()->updateDropRange(ctx.logicClickPos);
+    m_view->asItem()->setCursor(canDrop ? Qt::DragCopyCursor : QCursor());
+
+    return true;
+}
+
+void NotationViewInputController::mousePress_considerSelect(const ClickContext& ctx)
+{
     if (!ctx.hitElement) {
+        return;
+    }
+
+    m_hitElementWasAlreadySingleSelected = ctx.hitElement == viewInteraction()->selection()->element();
+
+    if (ctx.event->button() == Qt::LeftButton) {
+        if (ctx.event->modifiers() & Qt::ControlModifier) {
+            const std::vector<EngravingItem*> overlappingHitElements = viewInteraction()->hitElements(ctx.logicClickPos, hitWidth());
+            if (overlappingHitElements.size() > 1) {
+                cycleOverlappingHitElements(overlappingHitElements, ctx.hitStaff);
+                return;
+            }
+        }
+    } else if (ctx.event->button() == Qt::RightButton) {
+        if (ctx.hitElement->selected()) {
+            return;
+        }
+    }
+
+    SelectType selectType = SelectType::SINGLE;
+    if (ctx.event->modifiers() & Qt::ShiftModifier) {
+        selectType = SelectType::RANGE;
+    } else if (ctx.event->modifiers() & Qt::ControlModifier) {
+        selectType = SelectType::ADD;
+    } else {
+        const INotationSelectionPtr selection = viewInteraction()->selection();
+
+        if (selection->isRange()
+            && (selection->range()->containsItem(ctx.hitElement, ctx.hitStaff)
+                || selection->range()->containsPoint(ctx.logicClickPos))) {
+            m_shouldSelectOnLeftClickRelease = true;
+            return;
+        } else if (ctx.hitElement->selected()) {
+            if (selection->elements().size() > 1) {
+                m_shouldSelectOnLeftClickRelease = true;
+            }
+            return;
+        }
+    }
+
+    viewInteraction()->select({ ctx.hitElement }, selectType, ctx.hitStaff);
+}
+
+void NotationViewInputController::cycleOverlappingHitElements(const std::vector<EngravingItem*>& hitElements,
+                                                              staff_idx_t hitStaffIndex)
+{
+    const size_t numHitElements = hitElements.size();
+    size_t currTop = numHitElements - 1;
+    EngravingItem* e = hitElements[currTop];
+    std::set<EngravingItem*> selectedAtPosition;
+    bool found = false;
+
+    // e is the topmost element in stacking order,
+    // but we want to replace it with "first non-measure element after a selected element"
+    // (if such an element exists)
+    for (size_t i = 0; i <= numHitElements; ++i) {
+        if (found) {
+            e = hitElements[currTop];
+            if (!e->isMeasure()) {
+                break;
+            }
+        } else if (hitElements[currTop]->selected()) {
+            found = true;
+            selectedAtPosition.emplace(hitElements[currTop]);
+            e = nullptr;
+        }
+        currTop = (currTop + 1) % numHitElements;
+    }
+
+    if (e && !e->selected()) {
+        for (EngravingItem* selectedElem : selectedAtPosition) {
+            selectedElem->score()->deselect(selectedElem);
+        }
+        viewInteraction()->select({ e }, SelectType::ADD, hitStaffIndex);
+    }
+}
+
+bool NotationViewInputController::mousePress_considerDragOutgoingRange(const ClickContext& ctx)
+{
+    if (ctx.event->button() != Qt::LeftButton) {
         return false;
     }
 
-    INotationSelectionPtr selection = viewInteraction()->selection();
+    if (!ctx.hitElement || ctx.hitElement->isMeasure()) {
+        const INotationSelectionPtr selection = viewInteraction()->selection();
 
-    if (ctx.event->button() == Qt::LeftButton && ctx.event->modifiers() & Qt::ControlModifier) {
-        return true;
-    } else if (ctx.event->button() == Qt::LeftButton && ctx.event->modifiers() & Qt::ShiftModifier) {
-        return !selection->isRange() || !selection->range()->containsItem(ctx.hitElement, ctx.hitStaff);
-    } else if (ctx.event->button() == Qt::RightButton && selection->isRange()) {
-        return !selection->range()->containsItem(ctx.hitElement, ctx.hitStaff);
-    } else if (!ctx.hitElement->selected()) {
-        return true;
+        if (selection->isRange() && selection->range()->containsPoint(ctx.logicClickPos)) {
+            m_mouseDownInfo.dragAction = MouseDownInfo::DragOutgoingRange;
+            return true;
+        }
     }
 
     return false;
@@ -764,26 +929,14 @@ bool NotationViewInputController::needSelect(const ClickContext& ctx) const
 
 void NotationViewInputController::handleLeftClick(const ClickContext& ctx)
 {
-    if (ctx.isHitGrip) {
-        viewInteraction()->startEditGrip(ctx.logicClickPos);
+    if (!ctx.hitElement || !ctx.hitElement->selected()) {
         return;
-    } else {
-        viewInteraction()->endEditGrip();
     }
 
-    INotationSelectionPtr selection = viewInteraction()->selection();
-
-    if (!selection->isRange() && ctx.hitElement && ctx.hitElement->needStartEditingAfterSelecting()) {
-        if (ctx.hitElement->hasGrips() && !ctx.hitElement->isImage() && selection->elements().size() == 1) {
-            viewInteraction()->startEditGrip(ctx.hitElement, ctx.hitElement->defaultGrip());
-        } else {
-            viewInteraction()->startEditElement(ctx.hitElement, false);
-        }
-    }
-
-    if (!ctx.hitElement) {
-        viewInteraction()->endEditElement();
-        return;
+    // If it is the only selected element, start editing if needed
+    if (ctx.hitElement == viewInteraction()->selection()->element()
+        && ctx.hitElement->needStartEditingAfterSelecting()) {
+        viewInteraction()->startEditElement(ctx.hitElement);
     }
 
     if (ctx.hitElement->isPlayable()) {
@@ -797,12 +950,14 @@ void NotationViewInputController::handleLeftClick(const ClickContext& ctx)
 
 void NotationViewInputController::handleRightClick(const ClickContext& ctx)
 {
-    m_view->showContextMenu(selectionType(), ctx.event->pos());
+    m_mouseDownInfo.dragAction = MouseDownInfo::Nothing;
 
-    if (!ctx.hitElement) {
-        viewInteraction()->endEditElement();
-        return;
-    }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+    UNUSED(ctx);
+    // See also AbstractNotationPaintView::event for context menu event handling
+#else
+    m_view->showContextMenu(selectionType(), ctx.event->pos());
+#endif
 }
 
 bool NotationViewInputController::startTextEditingAllowed() const
@@ -815,6 +970,13 @@ void NotationViewInputController::updateTextCursorPosition()
 {
     if (viewInteraction()->isTextEditingStarted()) {
         viewInteraction()->changeTextCursorPosition(m_mouseDownInfo.logicalBeginPoint);
+
+        // Show text style popup
+        const TextBase* item = viewInteraction()->editedText();
+        if (AbstractElementPopupModel::hasTextStylePopup(item)
+            && (!item->isLyrics() || !item->empty())) {
+            m_view->showElementPopup(item->type());
+        }
     }
 }
 
@@ -859,14 +1021,14 @@ void NotationViewInputController::mouseMoveEvent(QMouseEvent* event)
         return;
     }
 
-    QPointF physicalDragDelta = event->pos() - m_mouseDownInfo.physicalBeginPoint;
+    const QPointF physicalDragDelta = event->pos() - m_mouseDownInfo.physicalBeginPoint;
 
-    bool isDragStarted = m_isCanvasDragged
-                         || viewInteraction()->isDragStarted()
-                         || viewInteraction()->isOutgoingDragStarted();
+    const bool isDragStarted = m_isCanvasDragged
+                               || viewInteraction()->isDragStarted()
+                               || viewInteraction()->isOutgoingDragStarted();
     if (!isDragStarted) {
         // only start drag operations after a minimum of movement:
-        bool canStartDrag = physicalDragDelta.manhattanLength() > 4;
+        const bool canStartDrag = physicalDragDelta.manhattanLength() > 4;
         if (!canStartDrag) {
             return;
         }
@@ -886,22 +1048,36 @@ void NotationViewInputController::mouseMoveEvent(QMouseEvent* event)
         }
         return;
     }
+    case MouseDownInfo::PasteRangeOnRelease: {
+        const PointF logicPos = m_view->toLogical(event->pos());
+
+        std::optional<bool> preserveMeasureAlignment;
+        if (physicalDragDelta.manhattanLength() > 4) {
+            preserveMeasureAlignment = false;
+        }
+
+        const bool canDrop = viewInteraction()->updateDropRange(logicPos, preserveMeasureAlignment);
+        m_view->asItem()->setCursor(canDrop ? Qt::DragCopyCursor : QCursor());
+        return;
+    }
     case MouseDownInfo::Nothing:
         return;
     case MouseDownInfo::Other:
         break;
     }
 
-    Qt::KeyboardModifiers keyState = event->modifiers();
+    const Qt::KeyboardModifiers keyState = event->modifiers();
 
     m_view->hideContextMenu();
-    m_view->hideElementPopup();
+    if (!viewInteraction()->isTextEditingStarted()) {
+        m_view->hideElementPopup();
+    }
 
-    PointF logicPos = m_view->toLogical(event->pos());
+    const PointF logicPos = m_view->toLogical(event->pos());
 
-    bool isNoteEnterMode = m_view->isNoteEnterMode();
-    bool isMiddleButton  = (event->buttons() & Qt::MiddleButton);
-    bool isDragObjectsAllowed = !(isNoteEnterMode || playbackController()->isPlaying() || isMiddleButton);
+    const bool isNoteEnterMode = m_view->isNoteEnterMode();
+    const bool isMiddleButton  = (event->buttons() & Qt::MiddleButton);
+    const bool isDragObjectsAllowed = !(isNoteEnterMode || playbackController()->isPlaying() || isMiddleButton);
     if (isDragObjectsAllowed) {
         const EngravingItem* hitElement = hitElementContext().element;
 
@@ -925,8 +1101,13 @@ void NotationViewInputController::mouseMoveEvent(QMouseEvent* event)
                 mode = DragMode::OnlyX;
             }
 
+            const std::vector<int> oldPitches = pitchesBeingDragged();
             viewInteraction()->drag(m_mouseDownInfo.logicalBeginPoint, logicPos, mode);
 
+            if (!oldPitches.empty() && oldPitches != pitchesBeingDragged()) {
+                playbackController()->playElements(m_notesBeingDragged);
+            }
+
             return;
         } else if (hitElement == nullptr && (keyState & Qt::ShiftModifier)) {
             if (!viewInteraction()->isDragStarted()) {
@@ -940,7 +1121,7 @@ void NotationViewInputController::mouseMoveEvent(QMouseEvent* event)
 
     // move canvas
     if (!isNoteEnterMode || isMiddleButton) {
-        PointF logicalDragDelta = logicPos - m_mouseDownInfo.logicalBeginPoint;
+        const PointF logicalDragDelta = logicPos - m_mouseDownInfo.logicalBeginPoint;
         m_view->moveCanvas(logicalDragDelta.x(), logicalDragDelta.y());
 
         m_isCanvasDragged = true;
@@ -964,14 +1145,49 @@ void NotationViewInputController::startDragElements(ElementType elementsType, co
     };
 
     viewInteraction()->startDrag(elements, elementsOffset, isDraggable);
+
+    if (!viewInteraction()->isDragStarted()) {
+        return;
+    }
+
+    for (const EngravingItem* item : elements) {
+        if (item->isNote()) {
+            m_notesBeingDragged.push_back(item);
+        }
+    }
 }
 
 void NotationViewInputController::mouseReleaseEvent(QMouseEvent* event)
 {
+    if (m_mouseDownInfo.dragAction == MouseDownInfo::Nothing) {
+        return;
+    }
+
     INotationInteractionPtr interaction = viewInteraction();
     INotationNoteInputPtr noteInput = interaction->noteInput();
     const EngravingItem* hitElement = hitElementContext().element;
 
+    DEFER {
+        m_mouseDownInfo.dragAction = MouseDownInfo::Nothing;
+        m_view->asItem()->setCursor(QCursor());
+    };
+
+    if (m_mouseDownInfo.dragAction == MouseDownInfo::PasteRangeOnRelease) {
+        INotationSelectionPtr selection = interaction->selection();
+        if (!selection->isRange() || !selection->canCopy()) {
+            viewInteraction()->endDrop();
+            return;
+        }
+        muse::ByteArray rangeData = selection->mimeData();
+        if (rangeData.empty()) {
+            viewInteraction()->endDrop();
+            return;
+        }
+        PointF logicPos = m_view->toLogical(event->pos());
+        viewInteraction()->dropRange(rangeData.toQByteArrayNoCopy(), logicPos, false);
+        return;
+    }
+
     if (event->modifiers() != Qt::ControlModifier && event->modifiers() != Qt::ShiftModifier) {
         if (!hitElement && !m_isCanvasDragged && !interaction->isGripEditStarted()
             && !interaction->isDragStarted() && !noteInput->isNoteInputMode()) {
@@ -1003,6 +1219,8 @@ void NotationViewInputController::mouseReleaseEvent(QMouseEvent* event)
     if (interaction->isOutgoingDragStarted()) {
         interaction->endOutgoingDrag();
     }
+
+    m_notesBeingDragged.clear();
 }
 
 void NotationViewInputController::handleLeftClickRelease(const QPointF& releasePoint)
@@ -1026,31 +1244,33 @@ void NotationViewInputController::handleLeftClickRelease(const QPointF& releaseP
         return;
     }
 
-    engraving::staff_idx_t staffIndex = ctx.staff ? ctx.staff->idx() : muse::nidx;
+    if (m_shouldSelectOnLeftClickRelease) {
+        m_shouldSelectOnLeftClickRelease = false;
+        engraving::staff_idx_t staffIndex = ctx.staff ? ctx.staff->idx() : muse::nidx;
 
-    INotationInteractionPtr interaction = viewInteraction();
-    interaction->select({ ctx.element }, SelectType::SINGLE, staffIndex);
+        INotationInteractionPtr interaction = viewInteraction();
+        interaction->select({ ctx.element }, SelectType::SINGLE, staffIndex);
 
-    if (ctx.element && ctx.element->needStartEditingAfterSelecting()) {
-        viewInteraction()->startEditElement(ctx.element, /*editTextualProperties*/ false);
+        if (ctx.element->needStartEditingAfterSelecting()) {
+            viewInteraction()->startEditElement(ctx.element);
+            return;
+        }
+    }
+
+    if (!m_hitElementWasAlreadySingleSelected) {
         return;
     }
 
-    if (m_shouldTogglePopupOnLeftClickRelease) {
+    // Same element clicked again while it was already selected.
+    // Either toggle popup or start text editing.
+
+    if (viewInteraction()->textEditingAllowed(ctx.element)) {
+        if (!viewInteraction()->isTextEditingStarted()) {
+            viewInteraction()->startEditText(ctx.element, m_mouseDownInfo.logicalBeginPoint);
+        }
+    } else {
         togglePopupForItemIfSupports(ctx.element);
     }
-
-    if (ctx.element != m_prevHitElement) {
-        return;
-    }
-
-    if (interaction->isTextEditingStarted()) {
-        return;
-    }
-
-    if (interaction->textEditingAllowed(ctx.element)) {
-        interaction->startEditText(ctx.element, m_mouseDownInfo.logicalBeginPoint);
-    }
 }
 
 void NotationViewInputController::mouseDoubleClickEvent(QMouseEvent* event)
@@ -1059,30 +1279,34 @@ void NotationViewInputController::mouseDoubleClickEvent(QMouseEvent* event)
         return;
     }
 
-    QTimer::singleShot(QApplication::doubleClickInterval(), [this]() {
+    // Can't pass `this` as the second argument, because not QObject. But `m_view` works as well.
+    QTimer::singleShot(QApplication::doubleClickInterval(), m_view->asItem(), [this]() {
         m_tripleClickPending = false;
     });
 
     m_tripleClickPending = true;
 
-    const INotationInteraction::HitElementContext& ctx = hitElementContext();
     if (viewInteraction()->isTextEditingStarted()) {
         viewInteraction()->selectText(mu::engraving::SelectTextType::Word);
         return;
-    } else if (viewInteraction()->textEditingAllowed(ctx.element)) {
-        viewInteraction()->startEditText(ctx.element, m_mouseDownInfo.logicalBeginPoint);
     }
 
-    PointF logicPos = m_view->toLogical(event->pos());
-    const EngravingItem* hitElement = viewInteraction()->hitElement(logicPos, hitWidth());
-
-    if (!hitElement) {
+    const INotationInteraction::HitElementContext& ctx = hitElementContext();
+    if (!ctx.element) {
         return;
     }
 
-    if (hitElement->isMeasure() && event->modifiers() == Qt::NoModifier) {
+    if (viewInteraction()->textEditingAllowed(ctx.element)) {
+        viewInteraction()->startEditText(ctx.element, m_mouseDownInfo.logicalBeginPoint);
+        return;
+    }
+
+    if (ctx.element->isMeasure() && event->modifiers() == Qt::NoModifier) {
         dispatcher()->dispatch("note-input", ActionData::make_arg1<PointF>(m_mouseDownInfo.logicalBeginPoint));
-    } else if (hitElement->isInstrumentName()) {
+        return;
+    }
+
+    if (ctx.element->isInstrumentName()) {
         m_shouldStartEditOnLeftClickRelease = true;
     }
 }
@@ -1113,29 +1337,61 @@ void NotationViewInputController::hoverMoveEvent(QHoverEvent* event)
     }
 }
 
+bool NotationViewInputController::isAnchorEditingEvent(QKeyEvent* event) const
+{
+    bool anchorEditingKeyCombo = (event->key() == Qt::Key_Left || event->key() == Qt::Key_Right) && event->modifiers() & Qt::ShiftModifier;
+    EngravingItem* selectedItem = viewInteraction()->selection()->element();
+    return selectedItem && selectedItem->allowTimeAnchor() && anchorEditingKeyCombo;
+}
+
 bool NotationViewInputController::shortcutOverrideEvent(QKeyEvent* event)
 {
-    const bool editTextKeysFound = event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter;
+    auto key = event->key();
+
+    const bool editTextKeysFound = key == Qt::Key_Return || key == Qt::Key_Enter;
     if (editTextKeysFound && startTextEditingAllowed()) {
         return true;
     }
 
+    if (key == Qt::Key_Escape && m_mouseDownInfo.dragAction == MouseDownInfo::PasteRangeOnRelease) {
+        return true;
+    }
+
     if (viewInteraction()->isElementEditStarted()) {
         return viewInteraction()->isEditAllowed(event);
     }
 
+    if (isAnchorEditingEvent(event)) {
+        return true;
+    }
+
     return tryPercussionShortcut(event);
 }
 
 void NotationViewInputController::keyPressEvent(QKeyEvent* event)
 {
+    auto key = event->key();
+
     if (startTextEditingAllowed() && (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter)) {
         dispatcher()->dispatch("edit-text");
         event->accept();
+    } else if (event->key() == Qt::Key_Escape && m_mouseDownInfo.dragAction == MouseDownInfo::PasteRangeOnRelease) {
+        // Cancel "Alt+click to paste range"
+        viewInteraction()->endDrop();
+        m_mouseDownInfo.dragAction = MouseDownInfo::Nothing;
+        m_view->asItem()->setCursor({});
+        event->accept();
     } else if (viewInteraction()->isElementEditStarted()) {
         viewInteraction()->editElement(event);
-    } else if (event->key() == Qt::Key_Shift) {
+        if (key == Qt::Key_Shift) {
+            viewInteraction()->updateTimeTickAnchors(event);
+        }
+    } else if (key == Qt::Key_Shift) {
+        viewInteraction()->updateTimeTickAnchors(event);
         updateShadowNotePopupVisibility();
+        return;
+    } else if (isAnchorEditingEvent(event)) {
+        viewInteraction()->moveElementAnchors(event);
     }
 
     updateShadowNotePopupVisibility(/*forceHide*/ true);
@@ -1149,6 +1405,7 @@ void NotationViewInputController::keyReleaseEvent(QKeyEvent* event)
 
     viewInteraction()->editElement(event);
     updateShadowNotePopupVisibility(/*forceHide*/ true);
+    viewInteraction()->updateTimeTickAnchors(event);
 }
 
 void NotationViewInputController::inputMethodEvent(QInputMethodEvent* event)
@@ -1204,7 +1461,7 @@ QVariant NotationViewInputController::inputMethodQuery(Qt::InputMethodQuery quer
 
 void NotationViewInputController::dragEnterEvent(QDragEnterEvent* event)
 {
-    const QMimeData* mimeData = event->mimeData();
+    const QMimeData* mimeData = dragController()->mimeData(event);
     IF_ASSERT_FAILED(mimeData) {
         return;
     }
@@ -1264,60 +1521,105 @@ void NotationViewInputController::dragEnterEvent(QDragEnterEvent* event)
 
 void NotationViewInputController::dragMoveEvent(QDragMoveEvent* event)
 {
-    const QMimeData* mimeData = event->mimeData();
+    const QMimeData* mimeData = dragController()->mimeData(event);
     IF_ASSERT_FAILED(mimeData) {
         return;
     }
 
+    PointF pos = m_view->toLogical(event->position());
+    Qt::KeyboardModifiers modifiers = event->modifiers();
+
+    bool isAccepted = false;
     if (mimeData->hasFormat(MIME_STAFFLLIST_FORMAT)) {
         bool isInternal = event->source() == m_view->asItem();
-        if (!isInternal || event->modifiers() & Qt::AltModifier) {
+        if (!isInternal || modifiers & Qt::AltModifier) {
             event->setDropAction(Qt::CopyAction);
         } else {
             event->setDropAction(Qt::MoveAction);
         }
+
+        isAccepted = viewInteraction()->updateDropRange(pos);
     } else {
         event->setDropAction(Qt::CopyAction);
-    }
 
-    PointF pos = m_view->toLogical(event->position());
-    Qt::KeyboardModifiers modifiers = event->modifiers();
-
-    bool isAccepted = false;
-    if (mimeData->hasFormat(MIME_STAFFLLIST_FORMAT)) {
-        isAccepted = viewInteraction()->isDropRangeAccepted(pos);
-    } else {
-        isAccepted = viewInteraction()->isDropSingleAccepted(pos, modifiers);
+        isAccepted = viewInteraction()->updateDropSingle(pos, modifiers);
     }
 
     event->setAccepted(isAccepted);
+
+    if (!uiConfiguration()->isSystemDragSupported()) {
+        m_lastDragMoveEvent = {
+            event->position(),
+            event->modifiers(),
+            event->dropAction(),
+            event->source()
+        };
+    }
 }
 
 void NotationViewInputController::dragLeaveEvent(QDragLeaveEvent*)
 {
+    if (!uiConfiguration()->isSystemDragSupported()) {
+        dropEvent(m_lastDragMoveEvent);
+    }
+
     viewInteraction()->endDrop();
+    m_mouseDownInfo.dragAction = MouseDownInfo::Nothing;
 }
 
 void NotationViewInputController::dropEvent(QDropEvent* event)
 {
-    const QMimeData* mimeData = event->mimeData();
-    IF_ASSERT_FAILED(mimeData) {
+    if (!uiConfiguration()->isSystemDragSupported()) {
+        event->setAccepted(false);
         return;
     }
 
-    PointF pos = m_view->toLogical(event->position());
-    Qt::KeyboardModifiers modifiers = event->modifiers();
+    DragMoveEvent de = {
+        event->position(),
+        event->modifiers(),
+        event->dropAction(),
+        event->source()
+    };
+
+    bool isAccepted = dropEvent(de, event->mimeData());
+    event->setAccepted(isAccepted);
+}
+
+bool NotationViewInputController::dropEvent(const DragMoveEvent& event, const QMimeData* mimeData)
+{
+    if (!mimeData) {
+        mimeData = dragController()->mimeData();
+    }
+
+    IF_ASSERT_FAILED(mimeData) {
+        return false;
+    }
+
+    PointF pos = m_view->toLogical(event.position);
+    Qt::KeyboardModifiers modifiers = event.modifiers;
 
     bool isAccepted = false;
     if (mimeData->hasFormat(MIME_STAFFLLIST_FORMAT)) {
-        bool isInternal = event->source() == m_view->asItem();
-        bool isMove = isInternal && event->dropAction() == Qt::MoveAction;
+        bool isInternal = event.source == m_view->asItem();
+        bool isMove = isInternal && event.dropAction == Qt::MoveAction;
         isAccepted = viewInteraction()->dropRange(mimeData->data(MIME_STAFFLLIST_FORMAT), pos, isMove);
     } else {
         isAccepted = viewInteraction()->dropSingle(pos, modifiers);
     }
 
-    event->setAccepted(isAccepted);
+    return isAccepted;
+}
+
+std::vector<int> NotationViewInputController::pitchesBeingDragged() const
+{
+    std::vector<int> pitches;
+    pitches.reserve(m_notesBeingDragged.size());
+
+    for (const EngravingItem* item : m_notesBeingDragged) {
+        pitches.push_back(toNote(item)->pitch());
+    }
+
+    return pitches;
 }
 
 float NotationViewInputController::hitWidth() const
@@ -1372,40 +1674,39 @@ void NotationViewInputController::togglePopupForItemIfSupports(const EngravingIt
 
     ElementType type = item->type();
 
-    if (AbstractElementPopupModel::supportsPopup(item)) {
-        m_view->toggleElementPopup(type, item->canvasBoundingRect());
+    if (AbstractElementPopupModel::hasElementEditPopup(item)) {
+        m_view->toggleElementPopup(type);
     }
 }
 
 void NotationViewInputController::updateShadowNotePopupVisibility(bool forceHide)
 {
     const mu::engraving::ShadowNote* shadowNote = viewInteraction()->shadowNote();
-    if (forceHide || !shadowNote || !AbstractElementPopupModel::supportsPopup(shadowNote)) {
+    if (forceHide || !shadowNote || !AbstractElementPopupModel::hasElementEditPopup(shadowNote)) {
         m_view->hideElementPopup(ElementType::SHADOW_NOTE);
         return;
     }
 
-    RectF noteHeadRect = shadowNote->symBbox(shadowNote->noteheadSymbol());
-    noteHeadRect.translate(shadowNote->canvasPos().x(), shadowNote->canvasPos().y());
-    m_view->showElementPopup(ElementType::SHADOW_NOTE, noteHeadRect);
+    m_view->showElementPopup(ElementType::SHADOW_NOTE);
 }
 
 EngravingItem* NotationViewInputController::resolveStartPlayableElement() const
 {
-    EngravingItem* hitElement = hitElementContext().element;
-
     if (playbackController()->isPlaying()) {
+        EngravingItem* hitElement = hitElementContext().element;
         return seekAllowed(hitElement) ? hitElement : nullptr;
     }
 
-    INotationSelectionPtr selection = viewInteraction()->selection();
-    if (!selection->isRange()) {
-        return hitElement;
+    const INotationSelectionPtr selection = viewInteraction()->selection();
+    const std::vector<EngravingItem*>& elements = selection->elements();
+
+    if (!selection->isRange() && !elements.empty()) {
+        return elements.back();
     }
 
-    EngravingItem* playbackStartElement = hitElement;
+    EngravingItem* playbackStartElement = hitElementContext().element;
 
-    for (EngravingItem* element: selection->elements()) {
+    for (EngravingItem* element: elements) {
         if (!element || element == playbackStartElement) {
             continue;
         }
