@@ -681,10 +681,10 @@ bool MixerChannelItem::askAboutChangingSound()
         IInteractive::ButtonData(changeBtn, muse::trc("playback", "Change sound"), true /*accent*/)
     };
 
-    IInteractive::Result result = interactive()->warning(muse::trc("playback", "Are you sure you want to change this sound?"),
-                                                         muse::trc("playback",
-                                                                   "Sound flags on this instrument may be reset, but staff text will remain. This action can’t be undone."),
-                                                         buttons, changeBtn, options);
+    IInteractive::Result result = interactive()->warningSync(muse::trc("playback", "Are you sure you want to change this sound?"),
+                                                             muse::trc("playback",
+                                                                       "Sound flags on this instrument may be reset, but staff text will remain. This action can’t be undone."),
+                                                             buttons, changeBtn, options);
 
     if (result.button() == changeBtn) {
         if (!result.showAgain()) {
