@@ -27,6 +27,7 @@
 #include "log.h"
 #include "translation.h"
 
+using namespace muse;
 using namespace mu::playback;
 using namespace muse::audio;
 using namespace mu::engraving;
@@ -263,7 +264,7 @@ void MixerPanelModel::setupConnections()
         }
     });
 
-    playback()->tracks()->inputParamsChanged().onReceive(
+    playback()->inputParamsChanged().onReceive(
         this, [this](const TrackSequenceId sequenceId, const TrackId trackId, AudioInputParams params) {
         if (m_currentTrackSequenceId != sequenceId) {
             return;
@@ -274,7 +275,7 @@ void MixerPanelModel::setupConnections()
         }
     });
 
-    playback()->audioOutput()->outputParamsChanged().onReceive(
+    playback()->outputParamsChanged().onReceive(
         this, [this](const TrackSequenceId sequenceId, const TrackId trackId, AudioOutputParams params) {
         if (m_currentTrackSequenceId != sequenceId) {
             return;
@@ -285,8 +286,8 @@ void MixerPanelModel::setupConnections()
         }
     });
 
-    playback()->audioOutput()->masterOutputParamsChanged().onReceive(this,
-                                                                     [this](AudioOutputParams params) {
+    playback()->masterOutputParamsChanged().onReceive(this,
+                                                      [this](AudioOutputParams params) {
         if (m_masterChannelItem) {
             loadOutputParams(m_masterChannelItem, std::move(params));
         }
@@ -410,7 +411,7 @@ MixerChannelItem* MixerPanelModel::buildInstrumentChannelItem(const TrackId trac
     item->setPanelSection(m_navigationSection);
     item->loadSoloMuteState(controller()->trackSoloMuteState(instrumentTrackId));
 
-    playback()->tracks()->inputParams(m_currentTrackSequenceId, trackId)
+    playback()->inputParams(m_currentTrackSequenceId, trackId)
     .onResolve(this, [this, trackId](AudioInputParams inParams) {
         if (MixerChannelItem* item = findChannelItem(trackId)) {
             item->loadInputParams(std::move(inParams));
@@ -421,18 +422,18 @@ MixerChannelItem* MixerPanelModel::buildInstrumentChannelItem(const TrackId trac
                << ", " << text;
     });
 
-    playback()->tracks()->trackName(m_currentTrackSequenceId, trackId)
-    .onResolve(this, [this, trackId](const TrackName& trackName) {
-        if (MixerChannelItem* item = findChannelItem(trackId)) {
-            item->setTitle(QString::fromStdString(trackName));
+    playback()->trackName(m_currentTrackSequenceId, trackId)
+    .onResolve(this, [this, trackId](const RetVal<TrackName>& trackName) {
+        if (trackName.ret) {
+            if (MixerChannelItem* item = findChannelItem(trackId)) {
+                item->setTitle(QString::fromStdString(trackName.val));
+            }
+        } else {
+            LOGE() << "unable to get track name, error: " << trackName.ret.toString();
         }
-    })
-    .onReject(this, [](int errCode, std::string text) {
-        LOGE() << "unable to get track name, error code: " << errCode
-               << ", " << text;
     });
 
-    playback()->audioOutput()->outputParams(m_currentTrackSequenceId, trackId)
+    playback()->outputParams(m_currentTrackSequenceId, trackId)
     .onResolve(this, [this, trackId](AudioOutputParams outParams) {
         if (MixerChannelItem* item = findChannelItem(trackId)) {
             loadOutputParams(item, std::move(outParams));
@@ -443,7 +444,7 @@ MixerChannelItem* MixerPanelModel::buildInstrumentChannelItem(const TrackId trac
                << ", " << text;
     });
 
-    playback()->audioOutput()->signalChanges(m_currentTrackSequenceId, trackId)
+    playback()->signalChanges(m_currentTrackSequenceId, trackId)
     .onResolve(this, [this, trackId](AudioSignalChanges signalChanges) {
         if (MixerChannelItem* item = findChannelItem(trackId)) {
             item->subscribeOnAudioSignalChanges(std::move(signalChanges));
@@ -455,11 +456,11 @@ MixerChannelItem* MixerPanelModel::buildInstrumentChannelItem(const TrackId trac
     });
 
     connect(item, &MixerChannelItem::inputParamsChanged, this, [this, trackId](const AudioInputParams& params) {
-        playback()->tracks()->setInputParams(m_currentTrackSequenceId, trackId, params);
+        playback()->setInputParams(m_currentTrackSequenceId, trackId, params);
     });
 
     connect(item, &MixerChannelItem::outputParamsChanged, this, [this, trackId](const AudioOutputParams& params) {
-        playback()->audioOutput()->setOutputParams(m_currentTrackSequenceId, trackId, params);
+        playback()->setOutputParams(m_currentTrackSequenceId, trackId, params);
     });
 
     connect(item, &MixerChannelItem::auxSendItemListChanged, this, [this, item]() {
@@ -483,18 +484,18 @@ MixerChannelItem* MixerPanelModel::buildAuxChannelItem(aux_channel_idx_t index,
     item->setPanelSection(m_navigationSection);
     item->loadSoloMuteState(audioSettings()->auxSoloMuteState(index));
 
-    playback()->tracks()->trackName(m_currentTrackSequenceId, trackId)
-    .onResolve(this, [this, trackId](const TrackName& trackName) {
-        if (MixerChannelItem* item = findChannelItem(trackId)) {
-            item->setTitle(QString::fromStdString(trackName));
+    playback()->trackName(m_currentTrackSequenceId, trackId)
+    .onResolve(this, [this, trackId](const RetVal<TrackName>& trackName) {
+        if (trackName.ret) {
+            if (MixerChannelItem* item = findChannelItem(trackId)) {
+                item->setTitle(QString::fromStdString(trackName.val));
+            }
+        } else {
+            LOGE() << "unable to get track name, error: " << trackName.ret.toString();
         }
-    })
-    .onReject(this, [](int errCode, std::string text) {
-        LOGE() << "unable to get track name, error code: " << errCode
-               << ", " << text;
     });
 
-    playback()->audioOutput()->outputParams(m_currentTrackSequenceId, trackId)
+    playback()->outputParams(m_currentTrackSequenceId, trackId)
     .onResolve(this, [this, trackId](AudioOutputParams outParams) {
         if (MixerChannelItem* item = findChannelItem(trackId)) {
             loadOutputParams(item, std::move(outParams));
@@ -505,7 +506,7 @@ MixerChannelItem* MixerPanelModel::buildAuxChannelItem(aux_channel_idx_t index,
                << ", " << text;
     });
 
-    playback()->audioOutput()->signalChanges(m_currentTrackSequenceId, trackId)
+    playback()->signalChanges(m_currentTrackSequenceId, trackId)
     .onResolve(this, [this, trackId](AudioSignalChanges signalChanges) {
         if (MixerChannelItem* item = findChannelItem(trackId)) {
             item->subscribeOnAudioSignalChanges(std::move(signalChanges));
@@ -517,7 +518,7 @@ MixerChannelItem* MixerPanelModel::buildAuxChannelItem(aux_channel_idx_t index,
     });
 
     connect(item, &MixerChannelItem::outputParamsChanged, this, [this, trackId](const AudioOutputParams& params) {
-        playback()->audioOutput()->setOutputParams(m_currentTrackSequenceId, trackId, params);
+        playback()->setOutputParams(m_currentTrackSequenceId, trackId, params);
     });
 
     connect(item, &MixerChannelItem::soloMuteStateChanged, this,
@@ -534,7 +535,7 @@ MixerChannelItem* MixerPanelModel::buildMasterChannelItem()
     item->setPanelSection(m_navigationSection);
     item->setTitle(muse::qtrc("playback", "Master"));
 
-    playback()->audioOutput()->masterOutputParams()
+    playback()->masterOutputParams()
     .onResolve(this, [this, item](AudioOutputParams outParams) {
         if (m_masterChannelItem && item == m_masterChannelItem) {
             loadOutputParams(item, std::move(outParams));
@@ -545,7 +546,7 @@ MixerChannelItem* MixerPanelModel::buildMasterChannelItem()
                << ", " << text;
     });
 
-    playback()->audioOutput()->masterSignalChanges()
+    playback()->masterSignalChanges()
     .onResolve(this, [this, item](AudioSignalChanges signalChanges) {
         if (m_masterChannelItem && item == m_masterChannelItem) {
             item->subscribeOnAudioSignalChanges(std::move(signalChanges));
@@ -557,7 +558,7 @@ MixerChannelItem* MixerPanelModel::buildMasterChannelItem()
     });
 
     connect(item, &MixerChannelItem::outputParamsChanged, this, [this](const AudioOutputParams& params) {
-        playback()->audioOutput()->setMasterOutputParams(params);
+        playback()->setMasterOutputParams(params);
     });
 
     return item;
