@@ -21,6 +21,8 @@
  */
 #include "printmodule.h"
 
+#include <memory>
+
 #include "modularity/ioc.h"
 
 #include "internal/printprovider.h"
@@ -35,5 +37,5 @@ std::string PrintModule::moduleName() const
 
 void PrintModule::registerExports()
 {
-    ioc()->registerExport<IPrintProvider>(moduleName(), new PrintProvider());
+    ioc()->registerExport<IPrintProvider>(moduleName(), std::make_shared<PrintProvider>(iocContext()));
 }
