@@ -37,6 +37,7 @@
 #include "engraving/compat/engravingcompat.h"
 #include "engraving/infrastructure/mscio.h"
 #include "engraving/engravingerrors.h"
+#include "engraving/rw/write/writecontext.h"
 
 #include "iprojectautosaver.h"
 #include "notation/notationerrors.h"
@@ -189,7 +190,8 @@ Ret NotationProject::doLoad(const muse::io::path_t& path, const muse::io::path_t
 
     // Load style if present
     if (!stylePath.empty()) {
-        m_engravingProject->masterScore()->loadStyle(stylePath.toQString());
+        muse::io::File styleFile(stylePath);
+        m_engravingProject->masterScore()->loadStyle(styleFile);
     }
 
     mu::engraving::compat::EngravingCompat::doPreLayoutCompatIfNeeded(m_engravingProject->masterScore());
@@ -226,14 +228,16 @@ Ret NotationProject::doLoad(const muse::io::path_t& path, const muse::io::path_t
     // Load view settings & solo-mute states (needs to be done after notations are created)
     m_masterNotation->notation()->viewState()->read(reader);
     m_masterNotation->notation()->soloMuteState()->read(reader);
-    for (IExcerptNotationPtr excerpt : m_masterNotation->excerpts()) {
-        if (!excerpt->hasFileName()) {
+    const int mscVersion = m_masterNotation->mscVersion();
+    for (const IExcerptNotationPtr& excerpt : m_masterNotation->excerpts()) {
+        const INotationPtr excerptNotation = excerpt->notation();
+        if (!excerpt->hasFileName() || mscVersion < 440) {
+            m_masterNotation->initNotationSoloMuteState(excerptNotation);
             continue;
         }
-
         muse::io::path_t ePath = u"Excerpts/" + excerpt->fileName() + u"/";
-        excerpt->notation()->viewState()->read(reader, ePath);
-        excerpt->notation()->soloMuteState()->read(reader, ePath);
+        excerptNotation->viewState()->read(reader, ePath);
+        excerptNotation->soloMuteState()->read(reader, ePath);
     }
 
     // Apply compat audio settings (needs to be done after notations are created)
@@ -275,7 +279,8 @@ Ret NotationProject::doImport(const muse::io::path_t& path, const muse::io::path
 
     // Load style if present
     if (!stylePath.empty()) {
-        score->loadStyle(stylePath.toQString());
+        muse::io::File styleFile(stylePath);
+        score->loadStyle(styleFile);
     }
 
     // Init ChordList
@@ -298,7 +303,7 @@ Ret NotationProject::doImport(const muse::io::path_t& path, const muse::io::path
 
     // Setup view state
     m_masterNotation->notation()->viewState()->makeDefault();
-    for (IExcerptNotationPtr excerpt : m_masterNotation->excerpts()) {
+    for (const IExcerptNotationPtr& excerpt : m_masterNotation->excerpts()) {
         excerpt->notation()->viewState()->makeDefault();
     }
 
@@ -348,7 +353,7 @@ Ret NotationProject::createNew(const ProjectCreateOptions& projectOptions)
 
     // Setup view state
     m_masterNotation->notation()->viewState()->makeDefault();
-    for (IExcerptNotationPtr excerpt : m_masterNotation->excerpts()) {
+    for (const IExcerptNotationPtr& excerpt : m_masterNotation->excerpts()) {
         excerpt->notation()->viewState()->makeDefault();
     }
 
@@ -464,13 +469,16 @@ Ret NotationProject::save(const muse::io::path_t& path, SaveMode saveMode, bool
 {
     TRACEFUNC;
 
+    Ret ret;
+    muse::io::path_t savePath = path;
+
     switch (saveMode) {
-    case SaveMode::SaveSelection:
-        return saveSelectionOnScore(path);
+    case SaveMode::SaveSelection: {
+        ret = saveSelectionOnScore(savePath);
+    } break;
     case SaveMode::Save:
     case SaveMode::SaveAs:
     case SaveMode::SaveCopy: {
-        muse::io::path_t savePath = path;
         if (savePath.empty()) {
             IF_ASSERT_FAILED(!m_path.empty()) {
                 return false;
@@ -484,19 +492,17 @@ Ret NotationProject::save(const muse::io::path_t& path, SaveMode saveMode, bool
         // Whether a backup file will be created depends on both the caller's and user's will
         bool shouldCreateBackup = createBackup && configuration()->createBackupBeforeSaving();
 
-        Ret ret = saveScore(savePath, suffix, shouldCreateBackup);
+        ret = saveScore(savePath, suffix, shouldCreateBackup);
         if (ret) {
             if (saveMode != SaveMode::SaveCopy) {
                 markAsSaved(savePath);
             }
         }
-
-        return ret;
-    }
-    case SaveMode::AutoSave:
-        std::string suffix = io::suffix(path);
+    } break;
+    case SaveMode::AutoSave: {
+        std::string suffix = io::suffix(savePath);
         if (suffix == IProjectAutoSaver::AUTOSAVE_SUFFIX) {
-            suffix = io::suffix(io::completeBasename(path));
+            suffix = io::suffix(io::completeBasename(savePath));
         }
 
         if (suffix.empty()) {
@@ -504,10 +510,53 @@ Ret NotationProject::save(const muse::io::path_t& path, SaveMode saveMode, bool
             suffix = engraving::MSCX;
         }
 
-        return saveScore(path, suffix, false /*generateBackup*/, false /*createThumbnail*/, true /*isAutosave*/);
+        ret = saveScore(savePath, suffix, false /*generateBackup*/, false /*createThumbnail*/, true /*isAutosave*/);
+    } break;
+    case SaveMode::SavePage:
+        ASSERT_X("Use savePage(path, pageNum)");
+        ret = muse::make_ret(Ret::Code::UnknownError);
+        break;
     }
 
-    return make_ret(notation::Err::UnknownError);
+    if (ret) {
+        m_saved.send(savePath, saveMode);
+    }
+
+    return ret;
+}
+
+muse::Ret NotationProject::savePage(const muse::io::path_t& path, const size_t pageNum)
+{
+    TRACEFUNC;
+
+    const MasterScore* score = m_masterNotation->masterScore();
+    IF_ASSERT_FAILED(pageNum < score->npages()) {
+        return make_ret(notation::Err::UnknownError);
+    }
+
+    const Page* page = score->pages().at(pageNum);
+    const std::vector<System*>& systems = page->systems();
+    if (systems.empty()) {
+        return make_ret(notation::Err::UnknownError);
+    }
+
+    write::WriteRange range;
+    range.startStaffIdx = 0;
+    range.endStaffIdx = score->nstaves();
+    range.startMeasure = systems.front()->first();
+    range.endMeasure = systems.back()->last();
+
+    Ret ret = writeRange(path, range);
+    if (ret) {
+        m_saved.send(path, SaveMode::SavePage);
+    }
+
+    return ret;
+}
+
+muse::async::Channel<path_t, SaveMode> NotationProject::saveComplited() const
+{
+    return m_saved;
 }
 
 Ret NotationProject::writeToDevice(QIODevice* device)
@@ -607,7 +656,7 @@ Ret NotationProject::doSave(const muse::io::path_t& path, engraving::MscIoMode i
         }
 
         MscWriter msczWriter(params);
-        Ret ret = writeProject(msczWriter, false /*onlySelection*/, createThumbnail);
+        Ret ret = writeProject(msczWriter, createThumbnail);
         msczWriter.close();
         if (params.device) {
             delete params.device;
@@ -730,7 +779,41 @@ Ret NotationProject::makeBackup(muse::io::path_t filePath)
     return ret;
 }
 
-Ret NotationProject::writeProject(MscWriter& msczWriter, bool onlySelection, bool createThumbnail)
+muse::Ret NotationProject::writeRange(const muse::io::path_t& path, const engraving::write::WriteRange& range)
+{
+    TRACEFUNC;
+
+    IF_ASSERT_FAILED(path != m_path) {
+        return make_ret(notation::Err::UnknownError);
+    }
+
+    // Check writable
+    if (fileSystem()->exists(path) && !fileSystem()->isWritable(path)) {
+        LOGE() << "failed save, not writable path: " << path;
+        return make_ret(notation::Err::UnknownError);
+    }
+
+    // Write project
+    std::string suffix = io::suffix(path);
+    MscWriter::Params params;
+    params.filePath = path.toQString();
+    params.mode = mscIoModeBySuffix(suffix);
+    IF_ASSERT_FAILED(params.mode != MscIoMode::Unknown) {
+        return make_ret(Ret::Code::InternalError);
+    }
+
+    MscWriter msczWriter(params);
+    Ret ret = writeProject(msczWriter, true, &range);
+
+    if (ret) {
+        QFile::setPermissions(path.toQString(),
+                              QFile::ReadOwner | QFile::WriteOwner | QFile::ReadUser | QFile::ReadGroup | QFile::ReadOther);
+    }
+    LOGI() << "success save file: " << path;
+    return ret;
+}
+
+Ret NotationProject::writeProject(MscWriter& msczWriter, bool createThumbnail, const write::WriteRange* range)
 {
     TRACEFUNC;
 
@@ -742,7 +825,7 @@ Ret NotationProject::writeProject(MscWriter& msczWriter, bool onlySelection, boo
     }
 
     // Write engraving project
-    ret = m_engravingProject->writeMscz(msczWriter, onlySelection, createThumbnail);
+    ret = m_engravingProject->writeMscz(msczWriter, createThumbnail, range);
     if (!ret) {
         LOGE() << "failed write engraving project to mscz: " << ret.toString();
         return make_ret(notation::Err::UnknownError);
@@ -755,9 +838,15 @@ Ret NotationProject::writeProject(MscWriter& msczWriter, bool onlySelection, boo
         return ret;
     }
 
-    // Write view settings and excerpt solo-mute states
+    // Write master view settings
     m_masterNotation->notation()->viewState()->write(msczWriter);
-    for (IExcerptNotationPtr excerpt : m_masterNotation->excerpts()) {
+
+    if (range) {
+        return make_ret(Ret::Code::Ok);
+    }
+
+    // Write excerpt view settings and solo-mute state
+    for (const IExcerptNotationPtr& excerpt : m_masterNotation->excerpts()) {
         muse::io::path_t path = u"Excerpts/" + excerpt->fileName() + u"/";
         excerpt->notation()->viewState()->write(msczWriter, path);
 
@@ -775,38 +864,38 @@ Ret NotationProject::saveSelectionOnScore(const muse::io::path_t& path)
 {
     TRACEFUNC;
 
-    IF_ASSERT_FAILED(path != m_path) {
-        return make_ret(notation::Err::UnknownError);
-    }
-
-    if (m_engravingProject->masterScore()->selectionEmpty()) {
+    const MasterScore* score = m_masterNotation->masterScore();
+    if (score->selectionEmpty()) {
         LOGE() << "failed save, empty selection";
         return make_ret(notation::Err::EmptySelection);
     }
-    // Check writable
-    if (fileSystem()->exists(path) && !fileSystem()->isWritable(path)) {
-        LOGE() << "failed save, not writable path: " << path;
-        return make_ret(notation::Err::UnknownError);
+
+    const Selection& selection = score->selection();
+
+    write::WriteRange range;
+    range.startStaffIdx = selection.staffStart();
+    range.endStaffIdx = selection.staffEnd();
+
+    // Make sure we select full parts
+    const Staff* sStaff = score->staff(range.startStaffIdx);
+    const Part* sPart = sStaff->part();
+    const Staff* eStaff = score->staff(range.endStaffIdx - 1);
+    const Part* ePart = eStaff->part();
+    range.startStaffIdx = score->staffIdx(sPart);
+    range.endStaffIdx = score->staffIdx(ePart) + ePart->nstaves();
+
+    range.startMeasure = selection.startSegment()->measure();
+    if (range.startMeasure && range.startMeasure->isMeasure() && toMeasure(range.startMeasure)->isMMRest()) {
+        range.startMeasure = toMeasure(range.startMeasure)->mmRestFirst();
     }
 
-    // Write project
-    std::string suffix = io::suffix(path);
-    MscWriter::Params params;
-    params.filePath = path.toQString();
-    params.mode = mscIoModeBySuffix(suffix);
-    IF_ASSERT_FAILED(params.mode != MscIoMode::Unknown) {
-        return make_ret(Ret::Code::InternalError);
+    if (const Segment* endSeg = selection.endSegment()) {
+        range.endMeasure = endSeg->measure()->next();
+    } else {
+        range.endMeasure = nullptr;
     }
 
-    MscWriter msczWriter(params);
-    Ret ret = writeProject(msczWriter, true);
-
-    if (ret) {
-        QFile::setPermissions(path.toQString(),
-                              QFile::ReadOwner | QFile::WriteOwner | QFile::ReadUser | QFile::ReadGroup | QFile::ReadOther);
-    }
-    LOGI() << "success save file: " << path;
-    return ret;
+    return writeRange(path, range);
 }
 
 Ret NotationProject::checkSavedFileForCorruption(MscIoMode ioMode, const muse::io::path_t& path,
@@ -901,7 +990,7 @@ void NotationProject::markAsUnsaved()
 
 void NotationProject::listenIfNeedSaveChanges()
 {
-    m_masterNotation->notation()->undoStack()->changesChannel().onReceive(this, [this](const ScoreChangesRange&) {
+    m_masterNotation->notation()->undoStack()->changesChannel().onReceive(this, [this](const ScoreChanges&) {
         bool isStackClean = m_masterNotation && m_masterNotation->notation()->undoStack()->isStackClean();
 
         if (isStackClean && !m_hasNonUndoStackChanges) {
@@ -1018,37 +1107,51 @@ ProjectMeta NotationProject::metaInfo() const
 {
     TRACEFUNC;
 
-    mu::engraving::MasterScore* score = m_masterNotation->masterScore();
+    const engraving::MasterScore* score = m_masterNotation->masterScore();
+    const std::map<String, String>& allTags = score->metaTags();
+
+    const auto initProjectMetaString = [&allTags](QString& string, const String& tag) {
+        const auto search = allTags.find(tag);
+        if (search == allTags.end()) {
+            LOGW() << "Project meta tag not found: " << tag;
+            return;
+        }
+        string = search->second;
+    };
 
     ProjectMeta meta;
     meta.filePath = m_path;
 
-    auto allTags = score->metaTags();
+    initProjectMetaString(meta.title, WORK_TITLE_TAG);
+    initProjectMetaString(meta.subtitle, SUBTITLE_TAG);
+    initProjectMetaString(meta.composer, COMPOSER_TAG);
+    initProjectMetaString(meta.arranger, ARRANGER_TAG);
+    initProjectMetaString(meta.lyricist, LYRICIST_TAG);
+    initProjectMetaString(meta.translator, TRANSLATOR_TAG);
+    initProjectMetaString(meta.copyright, COPYRIGHT_TAG);
 
-    meta.title = allTags[WORK_TITLE_TAG];
-    meta.subtitle = allTags[SUBTITLE_TAG];
-    meta.composer = allTags[COMPOSER_TAG];
-    meta.arranger = allTags[ARRANGER_TAG];
-    meta.lyricist = allTags[LYRICIST_TAG];
-    meta.translator = allTags[TRANSLATOR_TAG];
-    meta.copyright = allTags[COPYRIGHT_TAG];
-    meta.creationDate = QDate::fromString(allTags[CREATION_DATE_TAG], Qt::ISODate);
+    if (allTags.find(CREATION_DATE_TAG) != allTags.end()) {
+        meta.creationDate = QDate::fromString(allTags.at(CREATION_DATE_TAG), Qt::ISODate);
+    } else {
+        LOGW() << "Project meta tag not found: " << CREATION_DATE_TAG;
+    }
 
     meta.partsCount = score->excerpts().size();
 
-    meta.source = allTags[SOURCE_TAG];
-    meta.audioComUrl = allTags[AUDIO_COM_URL_TAG];
-    meta.platform = allTags[PLATFORM_TAG];
+    initProjectMetaString(meta.source, SOURCE_TAG);
+    initProjectMetaString(meta.audioComUrl, AUDIO_COM_URL_TAG);
+    initProjectMetaString(meta.platform, PLATFORM_TAG);
+
     meta.musescoreVersion = score->mscoreVersion();
     meta.musescoreRevision = score->mscoreRevision();
     meta.mscVersion = score->mscVersion();
 
-    for (const String& tag : muse::keys(allTags)) {
+    for (const auto& [tag, value] : allTags) {
         if (isRepresentedInProjectMeta(tag)) {
             continue;
         }
 
-        meta.additionalTags[tag] = allTags[tag].toQString();
+        meta.additionalTags[tag] = value.toQString();
     }
 
     return meta;
@@ -1074,8 +1177,8 @@ void NotationProject::setMetaInfo(const ProjectMeta& meta, bool undoable)
         { PLATFORM_TAG, meta.platform },
     };
 
-    for (const QString& tag : meta.additionalTags.keys()) {
-        tags[tag] = meta.additionalTags[tag].toString();
+    for (auto it = meta.additionalTags.cbegin(); it != meta.additionalTags.cend(); ++it) {
+        tags[it.key()] = it.value().toString();
     }
 
     MasterScore* score = m_masterNotation->masterScore();
